@@ -11,10 +11,6 @@
 #include "skeleton/toolbar.h"
 #include "skeleton/imgtoolbutton.h"
 
-namespace SKELETON
-{
-    class ImgToggleToolButton;
-}
 
 namespace ARTICLE
 {
@@ -28,7 +24,7 @@ namespace ARTICLE
         SKELETON::ImgToolButton m_button_drawout_or;
 
         // 実況
-        SKELETON::ImgToggleToolButton* m_button_live_play_stop;
+        Gtk::ToggleToolButton* m_button_live_play_stop;
 
       public:
 
