@@ -136,7 +136,7 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
       m_open_only_onedir( false ),
       m_cancel_expand( false ),
       m_expanding( 0 ),
-      m_editlistwin( NULL ),
+      m_editlistwin( nullptr ),
       m_set_bookmark( false )
 {
     m_scrwin.add( m_treeview );
@@ -147,12 +147,6 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
 
     m_treestore = Gtk::TreeStore::create( m_columns );
 
-#if !GTKMM_CHECK_VERSION(2,7,0)
-    // gtkmm26以下にはunset_model()が無いのでここでset_model()しておく
-    // それ以上は m_treeview.xml2tree() でセットする
-    m_treeview.set_treestore( m_treestore );
-#endif
-
     // Gtk::TreeStoreでset_fixed_height_mode()を使うとexpandしたときに
     // スクロールバーが誤動作するので使わないこと
 /*
@@ -174,15 +168,15 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
     m_treeview.create_column( CONFIG::get_tree_ypad() );
     m_treeview.set_column_for_height( 0 );
 
-#if GTKMM_CHECK_VERSION(2,12,0)
     // エクスパンダ表示とレベルインデント
     m_treeview.set_show_expanders( CONFIG::get_tree_show_expanders() );
     m_treeview.set_level_indentation( CONFIG::get_tree_level_indent() );
-#endif
 
     // treeviewのシグナルにコネクト
     m_treeview.signal_row_expanded().connect( sigc::mem_fun(*this, &BBSListViewBase::slot_row_exp ) );
     m_treeview.signal_row_collapsed().connect( sigc::mem_fun(*this, &BBSListViewBase::slot_row_col ) );
+    m_treeview.set_has_tooltip( true );
+    m_treeview.signal_query_tooltip().connect( sigc::mem_fun(*this, &BBSListViewBase::slot_query_tooltip) );
 
     m_treeview.sig_button_press().connect( sigc::mem_fun(*this, &BBSListViewBase::slot_button_press ) );
     m_treeview.sig_button_release().connect( sigc::mem_fun(*this, &BBSListViewBase::slot_button_release ) );
@@ -513,7 +507,7 @@ BBSListViewBase::~BBSListViewBase()
 #endif
 
     if( m_editlistwin ) delete m_editlistwin;
-    m_editlistwin = NULL;
+    m_editlistwin = nullptr;
 }
 
 
@@ -676,7 +670,6 @@ void BBSListViewBase::focus_out()
 {
     SKELETON::View::focus_out();
 
-    m_treeview.hide_tooltip();
     m_treeview.hide_popup();
 }
 
@@ -1155,8 +1148,6 @@ bool BBSListViewBase::slot_motion_notify( GdkEventMotion* event )
 
     if( m_treeview.get_path_at_pos( x, y, path, column, cell_x, cell_y ) && m_treeview.get_row( path ) ){
 
-        const int mrg = 16; // アイコンの横幅。計算するのが面倒だったのでとりあえず
-
         Gtk::TreeModel::Row row = m_treeview.get_row( path );
         Glib::ustring subject = row[ m_columns.m_name ];
         Glib::ustring url = row[ m_columns.m_url ];
@@ -1167,8 +1158,6 @@ bool BBSListViewBase::slot_motion_notify( GdkEventMotion* event )
         // 画像ポップアップ
         if( type == TYPE_IMAGE ){
 
-            m_treeview.hide_tooltip();
-
             if( DBIMG::get_type_ext( url ) != DBIMG::T_UNKNOWN && DBIMG::get_code( url ) != HTTP_INIT ){
 
                 if( m_treeview.pre_popup_url() != url ){
@@ -1180,19 +1169,12 @@ bool BBSListViewBase::slot_motion_notify( GdkEventMotion* event )
             else m_treeview.hide_popup();
         }
 
-        // ツールチップ
+        // ツールチップはslot_query_tooltipでセットする
         else{
-
             m_treeview.hide_popup();
-
-            Gdk::Rectangle rect;
-            m_treeview.get_cell_area( path, *column, rect );
-            m_treeview.set_tooltip_min_width( rect.get_width() - mrg );
-            m_treeview.set_str_tooltip( subject );
         }
     }
     else{
-        m_treeview.hide_tooltip();
         m_treeview.hide_popup();
     }
 
@@ -1740,7 +1722,7 @@ void BBSListViewBase::slot_opendir_as_board()
 
     const std::string tab = "newtab";
     const std::string mode = "";
-    CORE::core_set_command( "open_sidebar_board", get_url(), tab, mode, MISC::itostr( dirid ) );
+    CORE::core_set_command( "open_sidebar_board", get_url(), tab, mode, std::to_string( dirid ) );
 }
 
 
@@ -1757,7 +1739,7 @@ void BBSListViewBase::slot_create_vboard()
     CORE::DATA_INFO info;
     info.type = TYPE_VBOARD;
     info.parent = BBSLIST::get_admin()->get_win();
-    info.url = get_url() + SIDEBAR_SIGN + MISC::itostr( dirid );
+    info.url = get_url() + SIDEBAR_SIGN + std::to_string( dirid );
     info.name = path2name( m_path_selected );
     info.path = m_path_selected.to_string();
     list_info.push_back( info );
@@ -2517,11 +2499,12 @@ void BBSListViewBase::select_item( const std::string& url )
     if( ! m_ready_tree ) return;
     if( m_treestore->children().empty() ) return;
 
-    std::string url_item( url );
+    std::string url_item;
 
-    if( m_set_thread.find( url_item ) != m_set_thread.end()
-            || m_set_image.find( url_item ) != m_set_image.end()){
+    if( m_set_thread.find( url ) != m_set_thread.end()
+            || m_set_image.find( url ) != m_set_image.end()){
         // スレまたは画像の場合
+        url_item = url;
     }
     else {
         // 板以外の履歴は処理しない
@@ -3158,10 +3141,67 @@ void BBSListViewBase::slot_hide_editlistwin()
 #endif
 
     if( m_editlistwin ) delete m_editlistwin;
-    m_editlistwin = NULL;
+    m_editlistwin = nullptr;
 }
 
 
+//
+// ツールチップのセット
+//
+bool BBSListViewBase::slot_query_tooltip( int x, int y, bool keyboard_tooltip,
+                                          const Glib::RefPtr<Gtk::Tooltip>& tooltip )
+{
+    if( keyboard_tooltip ) return false;
+
+    int bin_x, bin_y;
+    m_treeview.convert_widget_to_bin_window_coords( x, y, bin_x, bin_y );
+#ifdef _DEBUG
+    std::cout << "BBSListViewBase::slot_query_tooltip"
+        << " x(" << x << ") y(" << y << ") bin_x(" << bin_x << ") bin_y(" << bin_y << ")" << std::endl;
+#endif
+
+    Gtk::TreeModel::Path path;
+    Gtk::TreeView::Column* column;
+    int cell_x, cell_y;
+    if( m_treeview.get_path_at_pos( bin_x, bin_y, path, column, cell_x, cell_y ) ) {
+        m_treeview.set_tooltip_row( tooltip, path );
+
+        const Gtk::TreeModel::Row row = m_treeview.get_row( path );
+        const Glib::ustring& subject = row[ m_columns.m_name ];
+        const Glib::ustring& url = row[ m_columns.m_url ];
+        const int type = row[ m_columns.m_type ];
+
+        m_treeview.reset_pre_popupurl( url );
+
+        // 画像ポップアップはslot_motion_notifyでセットする
+        if( type == TYPE_IMAGE ) return false;
+
+        Gdk::Rectangle cell_area;
+        m_treeview.get_cell_area( path, *column, cell_area );
+        const int capacity_width = m_treeview.get_width() - cell_area.get_x();
+
+        const auto layout = m_treeview.create_pango_layout( subject );
+        int pixel_width, ph;
+        layout->get_pixel_size( pixel_width, ph );
+
+        constexpr int icon_size{ 16 };
+#ifdef _DEBUG
+        std::cout << "BBSListViewBase::slot_query_tooltip" << " pixel_width(" << pixel_width
+            << ") + icon_size(" << icon_size << ")" << " > capacity_width(" << capacity_width << ")" << std::endl;
+#endif
+        // 板一覧の幅よりセルの内容が長いならツールチップを表示する
+        if( pixel_width + icon_size > capacity_width ) {
+            m_treeview.hide_popup();
+            tooltip->set_text( subject );
+            return true;
+        }
+    }
+    m_treeview.hide_popup();
+    return false;
+}
+
+
+
 //
 // XML保存
 //
