@@ -15,12 +15,7 @@
 using namespace BBSLIST;
 
 
-TreeColumns::TreeColumns()
-    : SKELETON::EditColumns()
-{}
-
-TreeColumns::~TreeColumns() noexcept
-{}
+TreeColumns::~TreeColumns() noexcept = default;
 
 void TreeColumns::setup_row( Gtk::TreeModel::Row& row,
                              const Glib::ustring url, const Glib::ustring name, const Glib::ustring data,
