@@ -85,7 +85,7 @@ enum
 
 
 
-#define DELETE_COLUMN(col) do{ if( ! col ) { delete col; col = NULL; } }while(0)
+#define DELETE_COLUMN(col) do{ if( ! col ) { delete col; col = nullptr; } }while(0)
 
 // set_sizing( Gtk::TREE_VIEW_COLUMN_FIXED ) を指定して append_columnする
 #define APPEND_COLUMN(col,title,model) do{                    \
@@ -98,18 +98,18 @@ m_treeview.append_column( *col ); \
 BoardViewBase::BoardViewBase( const std::string& url, const bool show_col_board )
     : SKELETON::View( url ),
       m_treeview( url, DNDTARGET_FAVORITE, true, CONFIG::get_fontname( FONT_BOARD ), COLOR_CHAR_BOARD, COLOR_BACK_BOARD, COLOR_BACK_BOARD_EVEN ),
-      m_col_mark( NULL ),
-      m_col_id( NULL ),
-      m_col_board( NULL ),
-      m_col_subject( NULL ),
-      m_col_res( NULL ),
-      m_col_str_load( NULL ),
-      m_col_str_new( NULL ),
-      m_col_since( NULL ),
-      m_col_write( NULL ),
-      m_col_access( NULL ),
-      m_col_speed( NULL ),
-      m_col_diff( NULL ),
+      m_col_mark( nullptr ),
+      m_col_id( nullptr ),
+      m_col_board( nullptr ),
+      m_col_subject( nullptr ),
+      m_col_res( nullptr ),
+      m_col_str_load( nullptr ),
+      m_col_str_new( nullptr ),
+      m_col_since( nullptr ),
+      m_col_write( nullptr ),
+      m_col_access( nullptr ),
+      m_col_speed( nullptr ),
+      m_col_diff( nullptr ),
       m_clicked( false ),
       m_col( COL_NUM_COL ),
       m_previous_col( COL_NUM_COL ),
@@ -137,21 +137,12 @@ BoardViewBase::BoardViewBase( const std::string& url, const bool show_col_board
     // ツリービュー設定
     m_liststore = Gtk::ListStore::create( m_columns );
 
-#if !GTKMM_CHECK_VERSION(2,7,0)
-    // gtkmm26以下にはunset_model()が無いのでここでset_model()しておく
-    m_treeview.set_model( m_liststore );
-#endif
-
-#if GTKMM_CHECK_VERSION(2,6,0)
-
     // セルを固定の高さにする
     // append_column する前に columnに対して set_sizing( Gtk::TREE_VIEW_COLUMN_FIXED ) すること
     m_treeview.set_fixed_height_mode( true );
 
 #ifdef _DEBUG
     std::cout << "BoardViewBase::BoardViewBase : m_treeview.set_fixed_height_mode\n";
-#endif
-
 #endif
 
     // 列のappend
@@ -177,6 +168,8 @@ BoardViewBase::BoardViewBase( const std::string& url, const bool show_col_board
     m_treeview.sig_key_press().connect( sigc::mem_fun(*this, &BoardViewBase::slot_key_press ) );
     m_treeview.sig_key_release().connect( sigc::mem_fun(*this, &BoardViewBase::slot_key_release ) );
     m_treeview.sig_scroll_event().connect( sigc::mem_fun(*this, &BoardViewBase::slot_scroll_event ) );
+    m_treeview.set_has_tooltip( true );
+    m_treeview.signal_query_tooltip().connect( sigc::mem_fun(*this, &BoardViewBase::slot_query_tooltip) );
     m_treeview.signal_drag_data_get().connect( sigc::mem_fun(*this, &BoardViewBase::slot_drag_data_get ) );
     m_treeview.sig_dropped_uri_list().connect( sigc::mem_fun(*this, &BoardViewBase::slot_dropped_url_list ) );
 
@@ -1288,9 +1281,7 @@ void BoardViewBase::update_view_impl( const std::vector< DBTREE::ArticleBase* >&
 #endif
 
     // 画面消去
-#if GTKMM_CHECK_VERSION(2,8,0)
     m_treeview.unset_model();
-#endif
 
     if( list_article.size() ){
 
@@ -1305,9 +1296,7 @@ void BoardViewBase::update_view_impl( const std::vector< DBTREE::ArticleBase* >&
             prepend_row( art, i + 1 );
         }
 
-#if GTKMM_CHECK_VERSION(2,8,0)
         m_treeview.set_model( m_liststore );
-#endif
 
         if( loading_fin ){
             if( m_list_draw_bg_articles.size() ) draw_bg_articles();
@@ -1370,8 +1359,6 @@ void BoardViewBase::focus_view()
 void BoardViewBase::focus_out()
 {
     SKELETON::View::focus_out();
-
-    m_treeview.hide_tooltip();
 }
 
 
@@ -1728,7 +1715,7 @@ void BoardViewBase::activate_act_before_popupmenu( const std::string& url )
 //
 Gtk::Menu* BoardViewBase::get_popupmenu( const std::string& url )
 {
-    Gtk::Menu* popupmenu = NULL;
+    Gtk::Menu* popupmenu = nullptr;
 
     // 削除サブメニュー
     if( url == "popup_menu_delete" ){
@@ -2131,27 +2118,6 @@ bool BoardViewBase::slot_motion_notify( GdkEventMotion* event )
     /// マウスジェスチャ
     get_control().MG_motion( event );
 
-    const int x = (int)event->x;
-    const int y = (int)event->y;
-    Gtk::TreeModel::Path path;
-    Gtk::TreeView::Column* column;
-    int cell_x;
-    int cell_y;
-
-    // ツールチップに文字列をセットする
-    if( m_treeview.get_path_at_pos( x, y, path, column, cell_x, cell_y ) ){
-
-        // 列幅よりもツールチップの幅が広い場合はツールチップを表示する
-        m_treeview.set_tooltip_min_width( column->get_width() );
-
-        if( column->get_title() == ITEM_NAME_BOARD ) m_treeview.set_str_tooltip( get_name_of_cell( path, m_columns.m_col_board ) );
-        else if( column->get_title() == ITEM_NAME_NAME ) m_treeview.set_str_tooltip( get_name_of_cell( path, m_columns.m_col_subject ) );
-        else if( column->get_title() == ITEM_NAME_SINCE ) m_treeview.set_str_tooltip( get_name_of_cell( path, m_columns.m_col_since ) );
-        else if( column->get_title() == ITEM_NAME_LASTWRITE ) m_treeview.set_str_tooltip( get_name_of_cell( path, m_columns.m_col_write ) );
-        else if( column->get_title() == ITEM_NAME_ACCESS ) m_treeview.set_str_tooltip( get_name_of_cell( path, m_columns.m_col_access ) );
-        else m_treeview.set_str_tooltip( std::string() );
-    }
-
     return true;
 }
 
@@ -2220,6 +2186,49 @@ bool BoardViewBase::slot_scroll_event( GdkEventScroll* event )
 }
 
 
+//
+// ツールチップのセット
+//
+bool BoardViewBase::slot_query_tooltip( int x, int y, bool keyboard_tooltip,
+                                        const Glib::RefPtr<Gtk::Tooltip>& tooltip )
+{
+    if( keyboard_tooltip ) return false;
+
+    int bin_x, bin_y;
+    m_treeview.convert_widget_to_bin_window_coords( x, y, bin_x, bin_y );
+
+    Gtk::TreeModel::Path path;
+    Gtk::TreeView::Column* column;
+    int cell_x, cell_y;
+    if( m_treeview.get_path_at_pos( bin_x, bin_y, path, column, cell_x, cell_y ) ) {
+        m_treeview.set_tooltip_cell( tooltip, &path, column, nullptr );
+
+        const Glib::ustring title = column->get_title();
+        Glib::ustring cell_text;
+        if( title == ITEM_NAME_BOARD ) cell_text = get_name_of_cell( path, m_columns.m_col_board );
+        else if( title == ITEM_NAME_NAME ) cell_text = get_name_of_cell( path, m_columns.m_col_subject );
+        else if( title == ITEM_NAME_SINCE ) cell_text = get_name_of_cell( path, m_columns.m_col_since );
+        else if( title == ITEM_NAME_LASTWRITE ) cell_text = get_name_of_cell( path, m_columns.m_col_write );
+        else if( title == ITEM_NAME_ACCESS ) cell_text = get_name_of_cell( path, m_columns.m_col_access );
+
+        // セルの内容が空ならツールチップを表示しない
+        if( cell_text.empty() ) return false;
+
+        const auto layout = m_treeview.create_pango_layout( cell_text );
+        int pixel_width, ph;
+        layout->get_pixel_size( pixel_width, ph );
+        constexpr int offset{ 8 };
+        // セルの内容の幅が列幅より小さいならツールチップを表示しない
+        if( pixel_width + offset < column->get_width() ) return false;
+
+        // ツールチップにセルの内容をセットする
+        tooltip->set_text( cell_text );
+        return true;
+    }
+    return false;
+}
+
+
 //
 // D&Dで受信側がデータ送信を要求してきた
 //
@@ -2608,7 +2617,7 @@ bool BoardViewBase::drawout( const bool force_reset )
 
     if( reset ) CORE::core_set_command( "set_info", "", "" );
     else if( ! hit ) CORE::core_set_command( "set_info", "", "検索結果： ヒット無し" );
-    else CORE::core_set_command( "set_info", "", "検索結果： " + MISC::itostr( hit ) + "件" );
+    else CORE::core_set_command( "set_info", "", "検索結果： " + std::to_string( hit ) + "件" );
 
     return true;
 }
@@ -2774,7 +2783,7 @@ void BoardViewBase::slot_preferences_article()
 //
 void BoardViewBase::back_viewhistory( const int count )
 {
-    BOARD::get_admin()->set_command( "back_viewhistory", get_url(), MISC::itostr( count ) );
+    BOARD::get_admin()->set_command( "back_viewhistory", get_url(), std::to_string( count ) );
 }
 
 
@@ -2783,7 +2792,7 @@ void BoardViewBase::back_viewhistory( const int count )
 //
 void BoardViewBase::forward_viewhistory( const int count )
 {
-    BOARD::get_admin()->set_command( "forward_viewhistory", get_url(), MISC::itostr( count ) );
+    BOARD::get_admin()->set_command( "forward_viewhistory", get_url(), std::to_string( count ) );
 }
 
 
