@@ -2,6 +2,9 @@
 
 //#define _DEBUG
 #include "jddebug.h"
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include "cache.h"
 
@@ -80,15 +83,26 @@ std::string CACHE::path_root()
 {
     if( root_path.empty() ){
 
-        const std::string jd_cache = MISC::getenv_limited( "JDIM_CACHE", MAX_SAFE_PATH );
-        root_path = jd_cache.empty() ? "~/.jd/" : jd_cache;
+        std::string jdim_cache = MISC::getenv_limited( "JDIM_CACHE", MAX_SAFE_PATH );
+        if( jdim_cache.empty() ) {
+#ifdef ENABLE_COMPAT_CACHE_DIR
+            root_path = MISC::getenv_limited( ENV_HOME, MAX_SAFE_PATH ) + "/.jd/";
+            if( CACHE::file_exists( root_path ) != CACHE::EXIST_DIR )
+#endif
+            {
+                root_path = Glib::get_user_cache_dir() + "/jdim/";
+            }
+        }
+        else {
+            root_path = std::move( jdim_cache );
+        }
 
-        if( root_path[ root_path.length() -1 ] != '/' ) root_path = root_path + "/";
-
-        if( root_path[ 0 ] == '~' ){
+        if( root_path.front() == '~' ) {
             std::string home = MISC::getenv_limited( ENV_HOME , MAX_SAFE_PATH );
             root_path.replace( 0, 1, home );
         }
+
+        if( root_path.back() != '/' ) root_path.push_back( '/' );
     }
 
     return root_path;
@@ -370,7 +384,7 @@ std::string CACHE::path_msglog()
 //
 std::string CACHE::path_completion( int mode )
 {
-    return CACHE::path_root() +  "comp" + MISC::itostr( mode ) + ".info";
+    return CACHE::path_root() +  "comp" + std::to_string( mode ) + ".info";
 }
 
 
@@ -926,7 +940,7 @@ bool CACHE::jdmv( const std::string& file_from, const std::string& file_to )
 //
 // 保存ダイアログを表示して file_from を file_to に保存する
 //
-// parent == NULL の時はメインウィンドウをparentにする
+// parent == nullptr の時はメインウィンドウをparentにする
 // file_toはデフォルトの保存先
 // 戻り値は保存先(保存に失敗したらempty())
 //
@@ -1010,7 +1024,7 @@ void CACHE::add_filter_to_diag( Gtk::FileChooserDialog& diag, const int type )
 //
 // ファイル選択ダイアログを表示する
 //
-// parent == NULL の時はメインウィンドウをparentにする
+// parent == nullptr の時はメインウィンドウをparentにする
 // open_path はデフォルトの参照先
 // multi == true なら複数選択可能
 // 戻り値は選択されたファイルのpathのリスト
@@ -1040,7 +1054,7 @@ std::vector< std::string > CACHE::open_load_diag( Gtk::Window* parent, const std
 //
 // 保存ファイル選択ダイアログを表示する
 //
-// parent == NULL の時はメインウィンドウをparentにする
+// parent == nullptr の時はメインウィンドウをparentにする
 // dirとnameはデフォルトの参照先
 // 戻り値は選択されたファイルのpath
 //
