@@ -44,6 +44,10 @@ namespace CONFIG
     void set_color( const int id, const std::string& color );
     void reset_colors();
 
+    // 書き込みビューでGTKテーマの設定を使用するか (GTK3版のみ)
+    bool get_use_message_gtktheme();
+    void set_use_message_gtktheme( const bool use );
+
     // ツリービューでgtkrcの設定を使用するか
     bool get_use_tree_gtkrc();
     void set_use_tree_gtkrc( const bool use );
@@ -84,13 +88,13 @@ namespace CONFIG
     bool get_aafont_enabled();
 
     // レスを参照するときに前に付ける文字
-    const std::string get_ref_prefix();
+    std::string get_ref_prefix();
 
     // 参照文字( ref_prefix ) の後のスペースの数
     int ref_prefix_space();
 
     // レスにアスキーアートがあると判定する正規表現
-    const std::string get_regex_res_aa();
+    std::string get_regex_res_aa();
     void set_regex_res_aa( const std::string& regex );
 
     // JD ホームページのアドレス
@@ -335,10 +339,10 @@ namespace CONFIG
     bool get_open_one_favorite();
 
     // デフォルトの書き込み名
-    const std::string get_write_name();
+    std::string get_write_name();
 
     // デフォルトのメールアドレス
-    const std::string get_write_mail();
+    std::string get_write_mail();
 
     // 書き込み時に書き込み確認ダイアログを出すかどうか
     bool get_always_write_ok();
@@ -584,6 +588,10 @@ namespace CONFIG
     int get_delete_img_in_thread();
     void set_delete_img_in_thread( const int set );
 
+    //最大表示可能レス数
+    int get_max_resnumber();
+    void set_max_resnumber( const int set );
+
     // FIFOの作成などにエラーがあったらダイアログを表示する
     bool get_show_diag_fifo_error();
     void set_show_diag_fifo_error( const bool set );
