@@ -15,16 +15,16 @@ namespace CONTROL
     {
       public:
 
-        MouseConfig();
+        using MouseKeyConf::MouseKeyConf;
         ~MouseConfig() noexcept;
 
         void load_conf() override;
 
         // 操作文字列取得
-        const std::string get_str_motions( const int id ) override;
+        std::string get_str_motions( const int id ) override;
 
         // IDからデフォルトの操作文字列取得
-        const std::string get_default_motions( const int id ) override;
+        std::string get_default_motions( const int id ) override;
 
       private:
 
