@@ -176,10 +176,8 @@ namespace DBTREE
         // ダウンロード用変数
         std::list< std::string > m_url_update_views; // CORE::core_set_command( "update_board" ) を送信するビューのアドレス
         JDLIB::Iconv* m_iconv;
-        char* m_rawdata;
-        char* m_rawdata_left;
-        size_t m_lng_rawdata;
-        size_t m_lng_rawdata_left;
+        std::string m_rawdata;
+        std::string m_rawdata_left;
 
         // 情報ファイルを読みこんだらtrueにして2度読みしないようにする
         bool m_read_info;
@@ -207,7 +205,7 @@ namespace DBTREE
         // remove_old_abone_thread() をキャンセルするか
         bool m_cancel_remove_abone_thread;
 
-        // NULL artice クラス
+        // Null artice クラス
         ArticleBase* m_article_null;
 
       protected:
