@@ -16,18 +16,19 @@ namespace DBTREE
       public:
 
         BoardJBBS( const std::string& root, const std::string& path_board,const std::string& name );
+        ~BoardJBBS() noexcept = default;
 
-        const std::string url_datpath() override;
+        std::string url_datpath() override;
 
         // 新スレ作成用のメッセージ変換
-        const std::string create_newarticle_message( const std::string& subject, const std::string& name,
-                                                     const std::string& mail, const std::string& msg ) override;
+        std::string create_newarticle_message( const std::string& subject, const std::string& name,
+                                               const std::string& mail, const std::string& msg ) override;
 
         // 新スレ作成用のbbscgi のURL
-        const std::string url_bbscgi_new() override;
+        std::string url_bbscgi_new() override;
         
         // 新スレ作成用のsubbbscgi のURL
-        const std::string url_subbbscgi_new() override;
+        std::string url_subbbscgi_new() override;
 
       private:
 
