@@ -56,8 +56,7 @@ namespace DBTREE
         std::list< MOVETABLE > m_movetable;
 
         XML::Document m_xml_document;
-        char* m_rawdata;
-        size_t m_lng_rawdata;
+        std::string m_rawdata;
         std::list< DBTREE::ETCBOARDINFO > m_etcboards; // 外部板情報
 
         // 移転処理用変数
@@ -65,7 +64,7 @@ namespace DBTREE
         std::set< std::string > m_analyzed_path_board; // XML 解析中に処理済みの板のpath
         std::string m_move_info;  // 移転したときにダイアログに表示する移転済み板の一覧
 
-        // NULL board クラス
+        // Null board クラス
         BoardBase* m_board_null;
 
         // get_board()のキャッシュ
