@@ -45,9 +45,9 @@ namespace DBTREE
 
       protected:
 
-        const std::string get_url() override;
-        const std::string get_path() override;
-        const std::string get_charset() override;
+        std::string get_url() override;
+        std::string get_path() override;
+        std::string get_charset() override;
 
         // ロード用データ作成
         void create_loaderdata( JDLIB::LOADERDATA& data ) override;
