@@ -69,12 +69,17 @@ std::string ENVIRONMENT::get_configure_args( const int mode )
     bool multi = false;
 
     // 省略形として"--with-"や"--enable-"などを取り出す
-    while( ( found_pos = args.find( "'--with-", search_pos ) ) != std::string::npos ||
-            ( found_pos = args.find( "'--enable-", search_pos ) ) != std::string::npos )
+    while( ( found_pos = args.find( "'--", search_pos ) ) != std::string::npos )
     {
-        size_t quote_pos = args.find( "'", found_pos + 1 );
+        const size_t quote_pos = args.find( "'", found_pos + 1 );
 
-        if( quote_pos != std::string::npos && quote_pos != end_quote_pos)
+        if( args.compare( found_pos + 3, 4, "with" ) != 0
+            && args.compare( found_pos + 3, 6, "enable" ) != 0
+            && args.compare( found_pos + 3, 7, "disable" ) != 0 )
+        {
+            search_pos = quote_pos + 1;
+        }
+        else if( quote_pos != std::string::npos && quote_pos != end_quote_pos )
         {
             // 項目が複数の場合は改行かスペースを付与
             if( multi )
@@ -100,41 +105,6 @@ std::string ENVIRONMENT::get_configure_args( const int mode )
 }
 
 
-//
-// SVNリビジョンとして表示する文字列を返す
-//
-std::string get_svn_revision( const char* rev = NULL )
-{
-    std::string svn_revision = "SVN:";
-
-    if( rev )
-    {
-        // "2000:2002MS"など[0-9:MS]の形式かどうか
-        bool valid = true;
-        unsigned int n;
-        const size_t rev_length = strlen( rev );
-        for( n = 0; n < rev_length; ++n )
-        {
-            if( (unsigned char)( rev[n] - 0x30 ) > 0x0A
-                && rev[n] != 'M'
-                && rev[n] != 'S' )
-            {
-                valid = false;
-                break;
-            }
-        }
-
-        if( valid ) svn_revision.append( std::string( "Rev." ) + std::string( rev ) );
-    }
-
-    if( svn_revision.compare( "SVN:" ) == 0 )
-    {
-        svn_revision.append( std::string( __DATE__ ) + "-" + std::string( __TIME__ ) );
-    }
-
-    return svn_revision;
-}
-
 //
 // GITリビジョンとして表示する文字列を返す
 // リビジョンが得られなかった場合（tarballのソース等）は、fallbackの日付を返す
@@ -215,20 +185,10 @@ std::string ENVIRONMENT::get_jdversion()
 {
     std::stringstream jd_version;
 
-#ifdef JDVERSION_SVN
-
-#ifdef SVN_REVISION
-    jd_version << get_svn_revision( SVN_REVISION );
-#else
-    jd_version << get_svn_revision( NULL );
-#endif // SVN_REVISION
-
-#else
     jd_version << MAJORVERSION << "."
                 << MINORVERSION << "."
                 << MICROVERSION << "-"
                 << JDTAG << get_git_revision(GIT_DATE, GIT_HASH, GIT_DIRTY, JDDATE_FALLBACK);
-#endif // JDVERSION_SVN
 
     return jd_version.str();
 }
@@ -269,16 +229,16 @@ std::string ENVIRONMENT::get_distname()
             {
                 // read size of ProductName
                 rc = RegQueryValueEx( hKey, "ProductName",
-                        NULL, NULL, NULL, &dwSize );
+                        nullptr, nullptr, nullptr, &dwSize );
                 if( rc == ERROR_SUCCESS && dwSize > 0 )
                 {
                     // get buffer
                     regVal = (char *)malloc( dwSize );
-                    if( regVal != NULL )
+                    if( regVal != nullptr )
                     {
                         // read ProductName
                         rc = RegQueryValueEx( hKey, "ProductName",
-                                NULL, NULL, (LPBYTE)regVal, &dwSize );
+                                nullptr, nullptr, (LPBYTE)regVal, &dwSize );
                         if( rc == ERROR_SUCCESS && strlen( regVal ) > 0 )
                         {
                             // may be contains "Windows" in the value
@@ -291,16 +251,16 @@ std::string ENVIRONMENT::get_distname()
 
                 // read size of CSDVersion
                 rc = RegQueryValueEx( hKey, "CSDVersion",
-                        NULL, NULL, NULL, &dwSize );
+                        nullptr, nullptr, nullptr, &dwSize );
                 if( rc == ERROR_SUCCESS && dwSize > 0 )
                 {
                     // get buffer
                     regVal = (char *)malloc( dwSize );
-                    if( regVal != NULL )
+                    if( regVal != nullptr )
                     {
                         // read CSDVersion
                         rc = RegQueryValueEx( hKey, "CSDVersion",
-                                NULL, NULL, (LPBYTE)regVal, &dwSize );
+                                nullptr, nullptr, (LPBYTE)regVal, &dwSize );
                         if( rc == ERROR_SUCCESS && strlen( regVal ) > 0 )
                         {
                             // ServicePack version
@@ -475,7 +435,7 @@ std::string ENVIRONMENT::get_distname()
 
 #ifdef HAVE_SYS_UTSNAME_H
 
-    char *sysname = 0, *release = 0, *machine = 0;
+    char *sysname = nullptr, *release = nullptr, *machine = nullptr;
 
     // システムコール uname() 準拠：SVr4, POSIX.1-2001.
     struct utsname* uts;
@@ -506,7 +466,7 @@ std::string ENVIRONMENT::get_distname()
     }
 
     free( uts );
-    uts = NULL;
+    uts = nullptr;
 
 #endif
 #endif // _WIN32
@@ -658,9 +618,6 @@ std::string ENVIRONMENT::get_jdinfo()
 
     jd_info <<
     "[バージョン] " << progname << " " << version << "\n" <<
-//#ifdef SVN_REPOSITORY
-//    "[リポジトリ ] " << SVN_REPOSITORY << "\n" <<
-//#endif
     "[ディストリ ] " << distribution << "\n" <<
     "[パッケージ] " << "バイナリ/ソース( <配布元> )" << "\n" <<
     "[ DE／WM ] " << desktop << "\n" <<
