@@ -24,7 +24,7 @@
 #include "jdlib/miscutil.h"
 #include "jdlib/miscmsg.h"
 
-IMAGE::ImageAdmin *instance_imageadmin = NULL;
+IMAGE::ImageAdmin *instance_imageadmin = nullptr;
 
 IMAGE::ImageAdmin* IMAGE::get_admin()
 {
@@ -37,7 +37,7 @@ IMAGE::ImageAdmin* IMAGE::get_admin()
 void IMAGE::delete_admin()
 {
     if( instance_imageadmin ) delete instance_imageadmin;
-    instance_imageadmin = NULL;
+    instance_imageadmin = nullptr;
 }
 
 
@@ -68,6 +68,12 @@ ImageAdmin::ImageAdmin( const std::string& url )
     m_left.signal_released().connect( sigc::mem_fun( *this, &ImageAdmin::slot_release_left ) );
     m_right.signal_released().connect( sigc::mem_fun( *this, &ImageAdmin::slot_release_right ) );
 
+    // マウスホイールによる画像ビューのタブ切り替えを設定する
+    m_tab.add_events( Gdk::SCROLL_MASK );
+#if GTKMM_CHECK_VERSION(3,3,18)
+    m_tab.add_events( Gdk::SMOOTH_SCROLL_MASK );
+#endif
+    m_tab.signal_scroll_event().connect( sigc::mem_fun( *this, &ImageAdmin::slot_scroll_event ) );
 
     m_tab.pack_start( m_scrwin );
     m_tab.pack_end( m_right, Gtk::PACK_SHRINK );
@@ -885,7 +891,7 @@ SKELETON::View* ImageAdmin::get_icon( const std::string& url, int& pos )
     }
 
     pos = -1;
-    return NULL;
+    return nullptr;
 }
 
 // 簡易版
@@ -915,7 +921,7 @@ SKELETON::View* ImageAdmin::get_nth_icon( const unsigned int n )
 SKELETON::View* ImageAdmin::get_current_icon()
 {
     SKELETON::View* view = get_current_view();
-    if( !view ) return NULL;
+    if( !view ) return nullptr;
     return get_icon( view->get_url() );
 }
 
@@ -935,7 +941,7 @@ SKELETON::View* ImageAdmin::get_view( const std::string& url )
         if( ( *it_view )->get_url() == url ) return ( *it_view );
     }
 
-    return NULL;
+    return nullptr;
 }
 
 
@@ -1020,6 +1026,37 @@ void ImageAdmin::slot_release_right()
 }
 
 
+//
+// タブのマウスホイールイベント
+//
+bool ImageAdmin::slot_scroll_event( GdkEventScroll* event )
+{
+    // 回転したらタブ切り替え
+    const char* command_name = nullptr;
+    if( event->direction == GDK_SCROLL_UP ) command_name = "tab_left";
+    else if( event->direction == GDK_SCROLL_DOWN ) command_name = "tab_right";
+#if GTKMM_CHECK_VERSION(3,3,18)
+    else if( event->direction == GDK_SCROLL_SMOOTH ) {
+        constexpr double smooth_scroll_factor{ 2.0 };
+        m_smooth_dy += smooth_scroll_factor * event->delta_y;
+        if( m_smooth_dy < -1.0 ) {
+            command_name = "tab_left";
+            m_smooth_dy = 0.0;
+        }
+        else if( m_smooth_dy > 1.0 ) {
+            command_name = "tab_right";
+            m_smooth_dy = 0.0;
+        }
+    }
+#endif // GTKMM_CHECK_VERSION(3,3,18)
+
+    if( command_name ) set_command( command_name );
+    set_command( "switch_admin" );
+
+    return true;
+}
+
+
 
 //
 // 画像ファイルのコピー
