@@ -45,7 +45,7 @@ using namespace IMAGE;
 
 ImageViewMain::ImageViewMain( const std::string& url )
     : ImageViewBase( url ),
-      m_scrwin( 0 ),
+      m_scrwin( nullptr ),
       m_length_prev( 0 ),
       m_show_status( false ),
       m_update_status( false ),
@@ -399,8 +399,8 @@ void ImageViewMain::update_status()
 //
 void ImageViewMain::add_tab_number()
 {
-    set_status( " [" + MISC::itostr( IMAGE::get_admin()->get_current_page() + 1 )
-                + "/" + MISC::itostr( IMAGE::get_admin()->get_tab_nums() ) + "] "
+    set_status( " [" + std::to_string( IMAGE::get_admin()->get_current_page() + 1 )
+                + "/" + std::to_string( IMAGE::get_admin()->get_tab_nums() ) + "] "
                 + get_status_local()
                 + " [" + MISC::get_filename( get_url() )
                 + " (" + MISC::get_hostname( get_url(), false ) + ")]" );
