@@ -183,7 +183,7 @@ Gtk::Menu* ImageViewIcon::get_popupmenu( const std::string& url )
         auto item = dynamic_cast< Gtk::MenuItem* >( *menu->get_children().begin() );
         auto label = dynamic_cast< Gtk::Label* >( item->get_child() );
         if( label ) label->set_text_with_mnemonic( ITEM_NAME_GO + std::string( " [ タブ数 " )
-                                                   + MISC::itostr( IMAGE::get_admin()->get_tab_nums() ) + " ](_M)" );
+                                                   + std::to_string( IMAGE::get_admin()->get_tab_nums() ) + " ](_M)" );
     }
 
     return menu;
@@ -191,24 +191,6 @@ Gtk::Menu* ImageViewIcon::get_popupmenu( const std::string& url )
 
 
 
-//
-// マウスホイールイベント
-//
-bool ImageViewIcon::slot_scroll_event( GdkEventScroll* event )
-{
-    // 回転したらタブ切り替え
-    int control = CONTROL::None;
-    if( event->direction == GDK_SCROLL_UP ) control = CONTROL::TabLeft;
-    if( event->direction == GDK_SCROLL_DOWN ) control = CONTROL::TabRight;
-
-    ImageViewBase::operate_view( control );
-    IMAGE::get_admin()->set_command( "switch_admin" );
-
-    return true;
-}
-
-
-
 //
 // D&D開始
 //
