@@ -25,7 +25,7 @@ std::list< std::string > MISC::get_lines( const std::string& str ){
         
     std::list< std::string > lines;
     size_t i = 0, i2 = 0, r = 0;
-    while ( ( i2 = str.find( "\n", i ) ) != std::string::npos ){
+    while ( ( i2 = str.find( '\n', i ) ) != std::string::npos ){
         r = 0;
         if( (i2 >= 1) && (str[ i2 - 1 ] == '\r') ) r = 1;
         if( i2 - i > 0 ){
@@ -576,18 +576,6 @@ int MISC::str_to_uint( const char* str, size_t& dig, size_t& n )
 }
 
 
-//
-// 数字　-> 文字変換
-//
-std::string MISC::itostr( const int n )
-{
-    std::ostringstream ss;
-    ss << n;
-
-    return ss.str();
-}
-
-
 //
 // listで指定した数字を文字に変換
 //
@@ -899,7 +887,7 @@ std::string MISC::html_escape( const std::string& str, const bool include_url )
 std::string MISC::html_unescape( const std::string& str )
 {
     if( str.empty() ) return str;
-    if( str.find( "&" ) == std::string::npos ) return str;
+    if( str.find( '&' ) == std::string::npos ) return str;
 
     std::string str_out;
     const size_t str_length = str.length();
@@ -1224,16 +1212,14 @@ std::string MISC::Iconv( const std::string& str, const std::string& coding_from,
 {
     if( coding_from == coding_to ) return str;
 
-    char* str_bk = ( char* ) malloc( str.length() + 64 );
-    strcpy( str_bk, str.c_str() );
+    std::string str_bk = str;
 
     JDLIB::Iconv* libiconv = new JDLIB::Iconv( coding_from, coding_to );
     int byte_out;
 
-    const std::string str_enc = libiconv->convert( str_bk, strlen( str_bk ), byte_out );
+    std::string str_enc = libiconv->convert( &*str_bk.begin(), str_bk.size(), byte_out );
 
     delete libiconv;
-    free( str_bk );
 
     return str_enc;
 }
@@ -1400,7 +1386,7 @@ int MISC::decode_spchar_number( const char* in_char, const int offset, const int
 
     int num = 0;
     if( offset == 2 ) num = atoi( str_num );
-    else num = strtol( str_num, NULL, 16 );
+    else num = strtol( str_num, nullptr, 16 );
 
     return sanitize_numeric_character_reference( num );
 }
@@ -1490,7 +1476,7 @@ int MISC::utf8toucs2( const char* utfstr, int& byte )
     else {
         byte = 1;
         ucs2 =  utfstr[ 0 ];
-        ERRMSG( "MISC::utf8toucs2 : invalid code = " + MISC::itostr( ucs2 ) );
+        ERRMSG( "MISC::utf8toucs2 : invalid code = " + std::to_string( ucs2 ) );
     }
 
     return ucs2;
@@ -1868,7 +1854,7 @@ void MISC::asc( const char* str1, std::string& str2, std::vector< int >& table_p
                     }
                 }
 
-                while( !flag_hkana && hkana_table1[ i ][ 0 ][ 0 ] != '\0' ){
+                while( hkana_table1[ i ][ 0 ][ 0 ] != '\0' ){
 
                     if( in1 == hkana_table1[ i ][ 0 ][ 0 ]
                             && in2 == hkana_table1[ i ][ 0 ][ 1 ]
@@ -1879,6 +1865,7 @@ void MISC::asc( const char* str1, std::string& str2, std::vector< int >& table_p
 
                         if( dakuten ) pos += 3;
                         flag_hkana = true;
+                        break;
                     }
                     ++i;
                 }
