@@ -120,9 +120,6 @@ namespace MISC
     // 戻り値: 数値
     int str_to_uint( const char* str, size_t& dig, size_t& n );
 
-    // 数字　-> 文字変換
-    std::string itostr( const int n );
-
     // listで指定した数字を文字に変換
     std::string intlisttostr( const std::list< int >& list_num );
 
@@ -155,7 +152,7 @@ namespace MISC
     // URL中のスキームを判別する
     // 戻り値 : スキームタイプ
     // length    : "http://"等の文字数
-    int is_url_scheme( const char* str_in, int* length = NULL );
+    int is_url_scheme( const char* str_in, int* length = nullptr );
     int is_url_scheme_impl( const char* str_in, int* length );
 
     // URLとして扱う文字かどうか判別する
