@@ -10,17 +10,14 @@
 #include "buildinfo.h"
 #endif
 
-// svn 版の時は JDVERSION_SVN をdefineする
-//#define JDVERSION_SVN
-
 // gitのリポジトリを使ってビルドしているときはリビジョンから日付を取得する
 // リビジョンが参照できない場合はJDDATE_FALLBACKを使う
 // SEE ALSO: ENVIRONMENT::get_jdversion()
 
 #define MAJORVERSION 0
-#define MINORVERSION 2
+#define MINORVERSION 3
 #define MICROVERSION 0
-#define JDDATE_FALLBACK    "20190720"
+#define JDDATE_FALLBACK    "20200118"
 #define JDTAG     ""
 
 //---------------------------------
@@ -28,7 +25,7 @@
 #define JDCOMMENT "JDim (JD improved) は gtkmm/GTK+ を用いた2chブラウザです。"
 #define JDCOPYRIGHT "(c) 2006-2015 JD project" "\n" \
                     "(c) 2017-2019 yama-natuki" "\n" \
-                    "(c) 2019 JDimproved project"
+                    "(c) 2019-2020 JDimproved project"
 #define JDBBS CONFIG::get_url_jdhp()+"cgi-bin/bbs/support/"
 #define JD2CHLOG CONFIG::get_url_jdhp()+"old2ch/"
 #define JDHELP "https://jdimproved.github.io/JDim/"
@@ -71,11 +68,7 @@
 
 // Two macros expansion is gcc preprocessor technic
 #define JDRC_VERSION_EXP(a,b,c,d,e) JDRC_VERSION_FMT(a,b,c,d,e)
-#ifdef JDVERSION_SVN
-#define JDRC_VERSION_FMT(a,b,c,d,e) #a "." #b "." #c "-svnversion"
-#else
 #define JDRC_VERSION_FMT(a,b,c,d,e) #a "." #b "." #c "-" d e
-#endif
 #define JDRC_VERSION_STR JDRC_VERSION_EXP( \
             MAJORVERSION, MINORVERSION, MICROVERSION, JDTAG, JDDATE_FALLBACK)
 
