@@ -63,11 +63,11 @@ enum
 
 MessageViewBase::MessageViewBase( const std::string& url )
     : SKELETON::View( url ),
-      m_post( 0 ),
-      m_preview( 0 ),
+      m_post( nullptr ),
+      m_preview( nullptr ),
       m_entry_name( CORE::COMP_NAME ),
       m_entry_mail( CORE::COMP_MAIL ),
-      m_text_message( NULL ),
+      m_text_message( nullptr ),
       m_enable_focus( true ),
       m_lng_str_enc( 0 ),
       m_counter( 0 ),
@@ -110,16 +110,16 @@ MessageViewBase::~MessageViewBase()
     CORE::get_completion_manager()->set_query( CORE::COMP_MAIL, mail );
 
     if( m_preview ) delete m_preview;
-    m_preview = NULL;
+    m_preview = nullptr;
 
     if( m_post ){
         m_post->terminate_load();
         delete m_post;
     }
-    m_post = NULL;
+    m_post = nullptr;
 
     if( m_iconv ) delete m_iconv;
-    m_iconv = NULL;
+    m_iconv = nullptr;
 
     SESSION::set_close_mes( ! is_locked() );
 }
@@ -161,7 +161,7 @@ void MessageViewBase::clock_in()
         m_counter = 0;
 
         // 書き込みから時間があまり経っていなければステータス表示を更新
-        if( time( NULL ) - DBTREE::article_write_time( get_url() ) < 60 * 60 ) show_status();
+        if( time( nullptr ) - DBTREE::article_write_time( get_url() ) < 60 * 60 ) show_status();
 
         // 書き込み規制経過時刻表示
         time_t left = DBTREE::board_write_leftsec( get_url() );
@@ -170,7 +170,7 @@ void MessageViewBase::clock_in()
             bool set_color = false;
             if( m_str_pass.empty() ) set_color = true;
 
-            m_str_pass = "規制中 " + MISC::itostr( left ) + " 秒 ";
+            m_str_pass = "規制中 " + std::to_string( left ) + " 秒 ";
 
             std::string force;
             if( SESSION::focused_admin() == SESSION::FOCUS_MESSAGE ) force = "force";
@@ -441,15 +441,8 @@ void MessageViewBase::pack_widget()
     m_check_fixname.set_label( "固定" );
     m_check_fixmail.set_label( "固定" );
 
-    constexpr const char* name_tip = "チェックすると名前欄を保存して固定にする";
-    constexpr const char* mail_tip = "チェックするとメール欄を保存して固定にする";
-#if GTKMM_CHECK_VERSION(2,12,0)
-    m_check_fixname.set_tooltip_text( name_tip );
-    m_check_fixmail.set_tooltip_text( mail_tip );
-#else
-    m_tooltip.set_tip( m_check_fixname, name_tip );
-    m_tooltip.set_tip( m_check_fixmail, mail_tip );
-#endif
+    m_check_fixname.set_tooltip_text( "チェックすると名前欄を保存して固定にする" );
+    m_check_fixmail.set_tooltip_text( "チェックするとメール欄を保存して固定にする" );
 
     set_name();
     set_mail();
@@ -463,9 +456,7 @@ void MessageViewBase::pack_widget()
     m_tool_entry_name.set_expand( true );
     m_tool_entry_mail.set_expand( true );
 
-#if GTKMM_CHECK_VERSION(2,12,0)
     m_toolbar_name_mail.set_icon_size( Gtk::ICON_SIZE_MENU );
-#endif
     m_toolbar_name_mail.set_toolbar_style( Gtk::TOOLBAR_ICONS );
     m_toolbar_name_mail.append( m_tool_name );
     m_toolbar_name_mail.append( m_tool_fixname );
@@ -616,7 +607,9 @@ void MessageViewBase::write()
     if( left
         && ! SESSION::loginbe() // BEログイン中はダイアログを表示しない
         ){
-        SKELETON::MsgDiag mdiag( get_parent_win(), "書き込み規制中です ( 残り " + MISC::itostr( left ) + " 秒 )\n\nもう暫くお待ち下さい。規制秒数が短くなった場合は板のプロパティからリセットできます。" );
+        constexpr const char* message =
+            " 秒 )\n\nもう暫くお待ち下さい。規制秒数が短くなった場合は板のプロパティからリセットできます。";
+        SKELETON::MsgDiag mdiag( get_parent_win(), "書き込み規制中です ( 残り " + std::to_string( left ) + message );
         mdiag.run();
         return;
     }
