@@ -6,8 +6,6 @@
 
 #include "aamenu.h"
 
-#include "jdlib/miscutil.h"
-
 #include "config/globalconf.h"
 
 #include "fontid.h"
@@ -81,7 +79,7 @@ void AAMenu::create_menuitem( Glib::RefPtr< Gtk::ActionGroup > actiongroup, Gtk:
     std::string shortcut = CORE::get_aamanager()->id2shortcut( id );
     if( ! shortcut.empty() ) aa_label = "[" + shortcut + "] " + aa_label;
 
-    std::string actname = "aa" + MISC::itostr( id );
+    std::string actname = "aa" + std::to_string( id );
     if( actiongroup->get_action( actname ) ) return; // 登録済み
 
 #ifdef _DEBUG
@@ -257,11 +255,7 @@ void AAMenu::slot_configured_popup( int width, int height )
 {
     int sw = get_screen()->get_width();
     int x, y;
-#if GTKMM_CHECK_VERSION(2,18,0)
     get_window()->get_root_coords( 0, 0, x, y );
-#else
-    get_window()->get_root_origin( x, y );
-#endif
 
 #ifdef _DEBUG
     std::cout << " AAMenu::slot_configured_popup w = " << width
