@@ -43,6 +43,9 @@ AboutDiag::AboutDiag( const Glib::ustring& title )
 }
 
 
+AboutDiag::~AboutDiag() noexcept = default;
+
+
 //
 // run()
 //
@@ -162,11 +165,19 @@ void AboutDiag::set_version( const Glib::ustring& version )
 {
     m_label_version.set_label( version );
 
+#if GTKMM_CHECK_VERSION(3,0,0)
+    Pango::FontDescription font_discription_version = m_label_version.get_style_context()->get_font();
+#else
     Pango::FontDescription font_discription_version = m_label_version.get_style()->get_font();
+#endif
     const int label_version_font_size = font_discription_version.get_size();
     font_discription_version.set_size( label_version_font_size * 5 / 3 );
     font_discription_version.set_weight( Pango::WEIGHT_BOLD );
+#if GTKMM_CHECK_VERSION(3,0,0)
+    m_label_version.override_font( font_discription_version );
+#else
     m_label_version.modify_font( font_discription_version );
+#endif
 }
 
 Glib::ustring AboutDiag::get_version()
@@ -303,6 +314,10 @@ void AboutDiag::set_environment_list()
     row[ column_name ] = "glibmmのバージョン";
     row[ column_value ] = ENVIRONMENT::get_glibmm_version();
 
+    row = *( liststore->append() );
+    row[ column_name ] = "TLSライブラリ";
+    row[ column_value ] = ENVIRONMENT::get_tlslib_version();
+
     row = *( liststore->append() );
     row[ column_name ] = "主なオプション";
     row[ column_value ] = ENVIRONMENT::get_configure_args( ENVIRONMENT::CONFIGURE_OMITTED );
