@@ -237,7 +237,7 @@ namespace SKELETON
 
         void open_list( const COMMAND_ARGS& command_list );
         virtual COMMAND_ARGS get_open_list_args( const std::string& url, const COMMAND_ARGS& command_list ){ return COMMAND_ARGS(); }
-        virtual View* create_view( const COMMAND_ARGS& command ){ return NULL; };
+        virtual View* create_view( const COMMAND_ARGS& command ){ return nullptr; };
         virtual View* get_view( const std::string& url );
 
         // url を含むビュークラスをリストで取得 ( url と一致するビューでは無い )
