@@ -29,7 +29,7 @@ DragableNoteBook::DragableNoteBook()
     , m_page( -1 )
     , m_dragging_tab( false )
     , m_dragable( false )
-    , m_down_arrow( NULL )
+    , m_down_arrow( nullptr )
 {
     set_spacing( 0 );
 
@@ -37,21 +37,13 @@ DragableNoteBook::DragableNoteBook()
     m_notebook_tab.sig_button_press().connect( sigc::mem_fun( *this, &DragableNoteBook::slot_button_press_event ) );
     m_notebook_tab.sig_button_release().connect( sigc::mem_fun( *this, &DragableNoteBook::slot_button_release_event ) );
 
-    m_notebook_tab.sig_tab_motion_event().connect( sigc::mem_fun(*this, &DragableNoteBook::slot_motion_event ) );
-    m_notebook_tab.sig_tab_leave_event().connect( sigc::mem_fun(*this, &DragableNoteBook::slot_leave_event ) );
-
     m_notebook_tab.sig_tab_drag_motion().connect( sigc::mem_fun(*this, &DragableNoteBook::slot_drag_motion ) );
 
     m_notebook_tab.sig_scroll_event().connect( sigc::mem_fun(*this, &DragableNoteBook::slot_scroll_event ) );
 
     m_hbox_tab.pack_start( m_notebook_tab );
     m_hbox_tab.pack_start( m_bt_tabswitch, Gtk::PACK_SHRINK );
-    constexpr const char* bt_tabswitch_tip = "タブの一覧表示";
-#if GTKMM_CHECK_VERSION(2,12,0)
-    m_bt_tabswitch.set_tooltip_text( bt_tabswitch_tip );
-#else
-    m_tooltip_tabswitch.set_tip( m_bt_tabswitch, bt_tabswitch_tip );
-#endif
+    m_bt_tabswitch.set_tooltip_text( "タブの一覧表示" );
 
     pack_start( m_hbox_tab, Gtk::PACK_SHRINK );
     pack_start( m_notebook_toolbar, Gtk::PACK_SHRINK );
@@ -79,16 +71,6 @@ DragableNoteBook::~DragableNoteBook()
 void DragableNoteBook::clock_in()
 {
     m_notebook_tab.clock_in();
-    m_tooltip.clock_in();
-}
-
-
-//
-// フォーカスアウト
-//
-void DragableNoteBook::focus_out()
-{
-    m_tooltip.hide_tooltip();
 }
 
 
@@ -381,8 +363,6 @@ void DragableNoteBook::remove_page( const int page, const bool adjust_tab )
 
     if( tablabel ) delete tablabel;
 
-    m_tooltip.hide_tooltip();
-
     if( ! get_n_pages() ) m_bt_tabswitch.hide_button();
 }
 
@@ -555,9 +535,6 @@ SKELETON::TabLabel* DragableNoteBook::create_tablabel( const std::string& url )
     m_control.get_eventbutton( CONTROL::DragStartButton, event );
     tablabel->set_dragable( m_dragable, event.button );
 
-    tablabel->sig_tab_motion_event().connect( sigc::mem_fun(*this, &DragableNoteBook::slot_motion_event ) );
-    tablabel->sig_tab_leave_event().connect( sigc::mem_fun(*this, &DragableNoteBook::slot_leave_event ) );
-
     tablabel->sig_tab_drag_begin().connect( sigc::mem_fun(*this, &DragableNoteBook::slot_drag_begin ) );
     tablabel->sig_tab_drag_data_get().connect( sigc::mem_fun(*this, &DragableNoteBook::slot_drag_data_get ) );
     tablabel->sig_tab_drag_end().connect( sigc::mem_fun(*this, &DragableNoteBook::slot_drag_end ) );
@@ -688,39 +665,6 @@ bool DragableNoteBook::slot_button_release_event( GdkEventButton* event )
 
 
 
-//
-// タブの中でマウスを動かした
-//
-void DragableNoteBook::slot_motion_event()
-{
-    const int page = m_notebook_tab.get_page_under_mouse();
-
-#ifdef _DEBUG
-    std::cout << "DragableNoteBook::slot_motion_event page = " << page << std::endl;
-#endif
-
-    // ツールチップにテキストをセット
-    if( page >= 0 && page < m_notebook_tab.get_n_pages() ){
-        SKELETON::TabLabel* tab = m_notebook_tab.get_tablabel( page );
-        if( tab ) m_tooltip.set_text( tab->get_fulltext() );
-    }
-    else m_tooltip.hide_tooltip();
-}
-
-
-//
-// タブからマウスが出た
-//
-void DragableNoteBook::slot_leave_event()
-{
-#ifdef _DEBUG
-    std::cout << "DragableNoteBook::slot_leave_event page\n";
-#endif
-
-    m_tooltip.hide_tooltip();
-}
-
-
 // notebook_tab の上でホイールを回した
 bool DragableNoteBook::slot_scroll_event( GdkEventScroll* event )
 {
@@ -729,36 +673,36 @@ bool DragableNoteBook::slot_scroll_event( GdkEventScroll* event )
 #endif
 
     bool ret = false;
+    int next_page;
 
-    // gtk3ではタブの循環に加え隣のタブへ切り替える処理も実装する必要がある
-    // REVIEW: GTK3版ではホイールによるタブの切り替えが動作しない環境がある
     if( event->direction == GDK_SCROLL_UP ) {
-        const int current_page = get_current_page();
-        if( current_page == 0 ) {
-            set_current_page( get_n_pages() - 1 );
-            ret = true;
-        }
-#if GTKMM_CHECK_VERSION(3,0,0)
-        else {
-            set_current_page( current_page - 1 );
-            ret = true;
-        }
-#endif
+        next_page = get_current_page() - 1; // If negative, the last page will be used.
+        ret = true;
     }
     else if( event->direction == GDK_SCROLL_DOWN ) {
-        const int current_page = get_current_page();
-        if( current_page == get_n_pages() - 1 ) {
-            set_current_page( 0 );
-            ret = true;
-        }
-#if GTKMM_CHECK_VERSION(3,0,0)
-        else {
-            set_current_page( current_page + 1 );
-            ret = true;
-        }
-#endif
+        next_page = ( get_current_page() + 1 ) % get_n_pages();
+        ret = true;
     }
+#if GTKMM_CHECK_VERSION(3,3,18)
+    else if( event->direction == GDK_SCROLL_SMOOTH ) {
+        constexpr double smooth_scroll_factor{ 4.0 };
+        m_smooth_dy += smooth_scroll_factor * event->delta_y;
+        if( m_smooth_dy < -1.0 ) {
+            next_page = get_current_page() - 1; // If negative, the last page will be used.
+            ret = true;
+            m_smooth_dy = 0.0;
+        }
+        else if( m_smooth_dy > 1.0 ) {
+            next_page = ( get_current_page() + 1 ) % get_n_pages();
+            ret = true;
+            m_smooth_dy = 0.0;
+        }
+    }
+#endif // GTKMM_CHECK_VERSION(3,3,18)
 
+    if( ret ) {
+        set_current_page( next_page );
+    }
     m_sig_tab_scrolled.emit( event );
 
     return ret;
