@@ -16,8 +16,6 @@
 #include "viewnote.h"
 #include "tabswitchbutton.h"
 
-#include "tooltip.h"
-
 #include "control/control.h"
 
 #include <gtkmm.h>
@@ -77,9 +75,6 @@ namespace SKELETON
 
         Gtk::HBox m_hbox_tab;
         TabSwitchButton m_bt_tabswitch; // タブの切り替えボタン
-#if !GTKMM_CHECK_VERSION(2,12,0)
-        Gtk::Tooltips m_tooltip_tabswitch;
-#endif
 
         bool m_show_tabs;
         bool m_show_toolbar;
@@ -94,14 +89,16 @@ namespace SKELETON
         // 入力コントローラ
         CONTROL::Control m_control;
 
-        Tooltip m_tooltip;
-
         bool m_dragable;
 
         SKELETON::IconPopup* m_down_arrow;
 
         Alloc_NoteBook m_alloc_old;
 
+#if GTKMM_CHECK_VERSION(3,3,18)
+        double m_smooth_dy{ 0.0 }; // GDK_SCROLL_SMOOTH のスクロール変化量
+#endif
+
       public:
 
         SIG_SWITCH_PAGE signal_switch_page(){ return m_sig_switch_page; }
@@ -117,7 +114,6 @@ namespace SKELETON
         ~DragableNoteBook();
 
         void clock_in();
-        void focus_out();
 
 #if !GTKMM_CHECK_VERSION(3,0,0)
         // 枠描画
@@ -201,10 +197,7 @@ namespace SKELETON
         // コントローラ
         CONTROL::Control& get_control(){ return m_control; }
 
-        // タブからくるシグナルにコネクトする
-        void slot_motion_event();
-        void slot_leave_event();
-
+        // タブのドラッグ・アンド・ドロップ処理
         void slot_drag_begin();
         void slot_drag_motion( const int page, const int tab_x, const int tab_y, const int tab_width );
         void slot_drag_data_get( Gtk::SelectionData& selection_data );
