@@ -43,7 +43,7 @@ DragTreeView::DragTreeView( const std::string& url, const std::string& dndtarget
       m_dndtarget( dndtarget ),
       m_dragging( false ),
       m_use_bg_even( false ),
-      m_popup_win( NULL ),
+      m_popup_win( nullptr ),
       m_popup_shown( false )
 {
 #ifdef _DEBUG
@@ -175,8 +175,6 @@ void DragTreeView::init_font( const std::string& fontname )
 #else
     modify_font( pfd );
 #endif
-
-    m_tooltip.modify_font_label( fontname );
 }
 
 
@@ -190,17 +188,6 @@ void DragTreeView::clock_in()
         m_popup_win->view()->clock_in();
         return;
     }
-
-    m_tooltip.clock_in();
-}
-
-
-//
-// ツールチップに文字をセット
-//
-void DragTreeView::set_str_tooltip( const std::string& text )
-{
-    m_tooltip.set_text( text );
 }
 
 
@@ -297,7 +284,7 @@ void DragTreeView::delete_popup()
 #endif
 
         delete m_popup_win;
-        m_popup_win = NULL;
+        m_popup_win = nullptr;
 
         m_pre_popup_url = std::string();
         m_popup_shown = false;
@@ -517,6 +504,21 @@ void DragTreeView::wheelscroll( GdkEventScroll* event )
 
     if( event->direction == GDK_SCROLL_UP ) val = MAX( 0, val - scr_inc );
     else if( event->direction == GDK_SCROLL_DOWN ) val = MIN( adj->get_upper() - adj->get_page_size(), val + scr_inc );
+#if GTKMM_CHECK_VERSION(3,3,18)
+    else if( event->direction == GDK_SCROLL_SMOOTH ) {
+        constexpr double smooth_scroll_factor = 4.0;
+        m_smooth_dy += smooth_scroll_factor * event->delta_y;
+        if( std::abs( m_smooth_dy ) > 1.0 ) {
+            val += std::copysign( scr_inc, m_smooth_dy );
+            m_smooth_dy = 0.0;
+        }
+
+        // チルトホイール(横スクロール)対応
+        constexpr double smooth_scroll_factor_x = 0.5;
+        auto hadj = get_hadjustment();
+        hadj->set_value( hadj->get_value() + scr_inc * smooth_scroll_factor_x * event->delta_x );
+    }
+#endif
     adj->set_value( val );
 
 #ifdef _DEBUG
@@ -535,7 +537,6 @@ void DragTreeView::wheelscroll( GdkEventScroll* event )
 
 bool DragTreeView::on_leave_notify_event( GdkEventCrossing* event )
 {
-    m_tooltip.hide_tooltip();
     if( ! is_mouse_on_popup() ){
         hide_popup();
         m_pre_popup_url = std::string();
@@ -552,7 +553,7 @@ void DragTreeView::slot_selection_changed()
     int size = get_selection()->get_selected_rows().size();
 
     std::string str;
-    if( size >= 2 ) str = "選択数 " + MISC::itostr( size );
+    if( size >= 2 ) str = "選択数 " + std::to_string( size );
     CORE::core_set_command( "set_info" ,"", str );
 }
 
