@@ -192,12 +192,12 @@ void EditTreeView::setup()
     std::cout << "EditTreeView::Setup url = " << m_url << std::endl;
 #endif
 
-    m_parent_win = NULL;
+    m_parent_win = nullptr;
 
     m_updated = false;
     m_dragging_on_tree = false;
     m_editable = false;
-    m_undo_buffer = NULL;
+    m_undo_buffer = nullptr;
     m_dnd_counter = 0;
     m_row_dest = Gtk::TreeRow();
 
@@ -343,9 +343,7 @@ void EditTreeView::xml2tree( XML::Document& document, Glib::RefPtr< Gtk::TreeSto
 
     treestore->clear();
 
-#if GTKMM_CHECK_VERSION(2,8,0)
     unset_model();
-#endif
 
     // 開いてるツリーの格納用
     std::list< Gtk::TreePath > list_path_expand;
@@ -353,9 +351,7 @@ void EditTreeView::xml2tree( XML::Document& document, Glib::RefPtr< Gtk::TreeSto
     // Domノードから Gtk::TreeStore をセット
     document.set_treestore( treestore, m_columns, root_name, list_path_expand );
 
-#if GTKMM_CHECK_VERSION(2,8,0)
     set_treestore( treestore );
-#endif
 
     // ディレクトリIDのセット(まだセットされていない場合)
     get_max_dirid();
@@ -1535,7 +1531,7 @@ void EditTreeView::path2info( CORE::DATA_INFO& info, const Gtk::TreePath& path )
 
     info.type = row[ m_columns.m_type ];
 
-    info.parent = NULL;
+    info.parent = nullptr;
 
     tmp_str = row[ m_columns.m_url ];
     info.url = tmp_str.raw();
