@@ -18,14 +18,25 @@ namespace SKELETON
 
       IconPopup( const int icon_id ) : Gtk::Window( Gtk::WINDOW_POPUP ){
 
-            Glib::RefPtr< Gdk::Pixmap > pixmap;
-            Glib::RefPtr< Gdk::Bitmap > bitmap;
-
             m_pixbuf = ICON::get_icon( icon_id );
             m_img.set( m_pixbuf );
 
+#if GTKMM_CHECK_VERSION(3,0,0)
+            // NOTE: アルファチャンネルが利用できない環境では背景を透過できない
+            set_decorated( false );
+            set_app_paintable( true );
+            auto screen = get_screen();
+            auto visual = screen->get_rgba_visual();
+            if( visual && screen->is_composited() ) {
+                gtk_widget_set_visual( GTK_WIDGET( gobj() ), visual->gobj() );
+            }
+#else
+            Glib::RefPtr< Gdk::Pixmap > pixmap;
+            Glib::RefPtr< Gdk::Bitmap > bitmap;
+
             m_pixbuf->render_pixmap_and_mask( pixmap, bitmap, 255 );
             shape_combine_mask( bitmap, 0, 0 );
+#endif // GTKMM_CHECK_VERSION(3,0,0)
 
             add( m_img );
             show_all_children();
