@@ -15,10 +15,14 @@ namespace SKELETON
     class JDToolbar : public Gtk::Toolbar
     {
     public:
-        JDToolbar() noexcept {}
+        JDToolbar();
+        ~JDToolbar() noexcept;
 
+        // GTK+3ではデフォルトの描画処理に任せる
+#if !GTKMM_CHECK_VERSION(3,0,0)
     protected:
         bool on_expose_event( GdkEventExpose* event ) override;
+#endif
     };
 }
 
