@@ -27,6 +27,7 @@ namespace SKELETON
       public:
 
         LabelEntry( const bool editable, const std::string& label, const std::string& text = std::string() );
+        ~LabelEntry() noexcept;
 
         SIG_ACTIVATE signal_activate(){ return m_sig_activate; }
 
@@ -36,7 +37,7 @@ namespace SKELETON
         void set_label( const std::string& label );
 
         void set_text( const std::string& text );
-        const Glib::ustring get_text();
+        Glib::ustring get_text() const;
 
         void grab_focus();
         bool has_grab();
