@@ -21,14 +21,14 @@ enum
 
 
 MenuButton::MenuButton( const bool show_arrow, Gtk::Widget& label )
-    : m_label( NULL ), m_arrow( NULL )
+    : m_label( nullptr ), m_arrow( nullptr )
 {
     setup( show_arrow, &label );
 }
 
 
 MenuButton::MenuButton( const bool show_arrow, const int id )
-    : m_label( NULL ), m_arrow( NULL )
+    : m_label( nullptr ), m_arrow( nullptr )
 {
     setup( show_arrow, Gtk::manage( new Gtk::Image( ICON::get_icon( id ) ) ), Gtk::PACK_SHRINK );
 }
@@ -39,7 +39,7 @@ void MenuButton::setup( const bool show_arrow, Gtk::Widget* label, Gtk::PackOpti
     const int space = 4;
 
     m_label = label;
-    m_popupmenu =  NULL;
+    m_popupmenu =  nullptr;
     m_on_arrow = false;
     m_enable_sig_clicked = true;
 
@@ -69,7 +69,7 @@ void MenuButton::setup( const bool show_arrow, Gtk::Widget* label, Gtk::PackOpti
     Glib::RefPtr< Gtk::ActionGroup > actiongroup = Gtk::ActionGroup::create();
     Glib::RefPtr< Gtk::AccelGroup > agroup  = CORE::get_mainwindow()->get_accel_group();
     for( size_t i = 0 ; i < MAX_MENU_SIZE; ++i ){
-        Glib::RefPtr< Gtk::Action > action = Gtk::Action::create( "menu" + MISC::itostr( i ), "dummy" );
+        Glib::RefPtr< Gtk::Action > action = Gtk::Action::create( "menu" + std::to_string( i ), "dummy" );
         action->set_accel_group( agroup );
         Gtk::MenuItem* item = Gtk::manage( action->create_menu_item() );
         actiongroup->add( action, sigc::bind< int >( sigc::mem_fun( *this, &MenuButton::slot_menu_selected ), i ) );
@@ -89,14 +89,9 @@ MenuButton::~MenuButton()
 
 void MenuButton::set_tooltip_arrow( const std::string& tooltip )
 {
-#if GTKMM_CHECK_VERSION(2,12,0)
     if( m_arrow ) {
         m_arrow->set_tooltip_text( tooltip );
     }
-#else
-    // gtkmm-2.12.0より前のバージョンはボタンの中のWidgetにツールチップを設定できない
-    m_tooltip_arrow.set_tip( *this, tooltip );
-#endif
 }
 
 
@@ -111,7 +106,7 @@ void MenuButton::append_menu( std::vector< std::string >& items )
         for( int i = 0; i < menusize; ++i ) m_popupmenu->remove( *m_menuitems[ i ] );
         delete m_popupmenu;
     }
-    m_popupmenu = NULL;
+    m_popupmenu = nullptr;
 
     if( ! items.size() ) return;
 
@@ -120,7 +115,7 @@ void MenuButton::append_menu( std::vector< std::string >& items )
     const size_t size = MIN( items.size(), MAX_MENU_SIZE );
     for( size_t i = 0 ; i < size; ++i ){
 
-        Gtk::MenuItem* item = NULL;
+        Gtk::MenuItem* item = nullptr;
 
         if( items[ i ] == "separator" ){
             item = Gtk::manage( new Gtk::SeparatorMenuItem() );
