@@ -25,9 +25,6 @@ namespace SKELETON
         std::vector< Gtk::MenuItem* > m_menuitems;
         Gtk::Widget* m_label;
 
-#if !GTKMM_CHECK_VERSION(2,12,0)
-        Gtk::Tooltips m_tooltip_arrow;
-#endif
         Gtk::Arrow* m_arrow;
 
         bool m_on_arrow;
