@@ -122,7 +122,7 @@ bool TabNotebook::paint( GdkEventExpose* event )
 
     if( ! notebook->first_tab ) notebook->first_tab = notebook->children;
 
-    GtkNotebookPage* page = NULL;
+    GtkNotebookPage* page = nullptr;
     if( ! GTK_WIDGET_MAPPED( notebook->cur_page->tab_label ) ) page = GTK_NOTEBOOK_PAGE( notebook->first_tab );
     else page = notebook->cur_page;
 
@@ -284,15 +284,10 @@ void TabNotebook::get_arrow_rect( GtkWidget *widget, const GtkNotebook *notebook
     GdkRectangle event_window_pos;
     if( get_event_window_position( widget, notebook, &event_window_pos ) ){
 
-#if GTKMM_CHECK_VERSION(2,9,0)
         gtk_widget_style_get( widget,
                               "scroll-arrow-hlength", &rectangle->width,
                               "scroll-arrow-vlength", &rectangle->height,
-                              NULL );
-#else
-        // gtk+-2.9.1より前は 12 で固定
-        rectangle->width = rectangle->height = 12;
-#endif
+                              nullptr );
 
         if( before ) rectangle->x = event_window_pos.x;
         else rectangle->x = event_window_pos.x + event_window_pos.width - rectangle->width;
@@ -307,7 +302,7 @@ void TabNotebook::get_arrow_rect( GtkWidget *widget, const GtkNotebook *notebook
 #if !GTKMM_CHECK_VERSION(3,0,0)
 gboolean TabNotebook::get_event_window_position( const GtkWidget *widget, const GtkNotebook *notebook, GdkRectangle *rectangle )
 {
-    GtkNotebookPage* visible_page = NULL;
+    GtkNotebookPage* visible_page = nullptr;
     GList* children = notebook->children;
     while( children ){
 
@@ -348,11 +343,7 @@ class DummyWidget : public Gtk::Widget
 public:
     DummyWidget() : Gtk::Widget()
     {
-#if GTKMM_CHECK_VERSION(2,18,0)
         set_has_window( false );
-#else
-        set_flags( Gtk::NO_WINDOW );
-#endif
     }
     ~DummyWidget() noexcept = default;
 };
@@ -578,6 +569,7 @@ void TabNotebook::set_tab_fulltext( const std::string& str, int page )
     SKELETON::TabLabel* tablabel = get_tablabel( page );
     if( tablabel && str != tablabel->get_fulltext() ){
         tablabel->set_fulltext( str );
+        tablabel->set_tooltip_text( str );
         if( m_fixtab ) tablabel->resize_tab( str.length() );
         else adjust_tabwidth();
     }
