@@ -18,13 +18,15 @@ namespace SKELETON
 
     class TabSwitchButton: public Gtk::Notebook
     {
+#if !GTKMM_CHECK_VERSION(3,0,0)
         DragableNoteBook* m_parent;
+#endif
 
         Gtk::VBox m_vbox;
         Gtk::Button m_button;
-        Gtk::Arrow m_arrow;
+        Gtk::Arrow m_arrow{ Gtk::ARROW_DOWN, Gtk::SHADOW_NONE };
 
-        bool m_shown;
+        bool m_shown = false;
 
       public:
 
@@ -35,9 +37,11 @@ namespace SKELETON
         void show_button();
         void hide_button();
 
+#if !GTKMM_CHECK_VERSION(3,0,0)
       protected:
 
         bool on_expose_event( GdkEventExpose* event ) override;
+#endif
     };
 }
 
