@@ -7,7 +7,6 @@
 #include "admin.h"
 #include "view.h"
 #include "imgtoolbutton.h"
-#include "imgtoggletoolbutton.h"
 #include "menubutton.h"
 #include "toolmenubutton.h"
 #include "backforwardbutton.h"
@@ -27,7 +26,6 @@
 #include "command.h"
 #include "prefdiagfactory.h"
 
-#include <gtk/gtk.h>  // gtk_separator_tool_item_set_draw
 #if !GTKMM_CHECK_VERSION(3,0,0)
 #include <gtk/gtkbutton.h>
 #endif
@@ -46,42 +44,40 @@ ToolBar::ToolBar( Admin* admin )
       m_buttonbar_shown( false ),
       m_buttonbar_packed( false ),
 
-      m_tool_label( NULL ),
-      m_ebox_label( NULL ),
-      m_label( NULL ),
+      m_tool_label( nullptr ),
+      m_ebox_label( nullptr ),
+      m_label( nullptr ),
 
-      m_searchbar( NULL ),
+      m_searchbar( nullptr ),
       m_searchbar_shown( false ),
       m_searchbar_packed( false ),
-      m_button_open_searchbar( NULL ),
-      m_button_close_searchbar( NULL ),
-      m_button_up_search( NULL ),
-      m_button_down_search( NULL ),
-      m_button_clear_highlight( NULL ),
+      m_button_open_searchbar( nullptr ),
+      m_button_close_searchbar( nullptr ),
+      m_button_up_search( nullptr ),
+      m_button_down_search( nullptr ),
+      m_button_clear_highlight( nullptr ),
 
-      m_tool_search( NULL ),
-      m_entry_search( NULL ),
+      m_tool_search( nullptr ),
+      m_entry_search( nullptr ),
 
-      m_label_board( NULL ),
-      m_button_board( NULL ),
+      m_label_board( nullptr ),
+      m_button_board( nullptr ),
 
-      m_button_write( NULL ),
-      m_button_reload( NULL ),
-      m_button_stop( NULL ),
-      m_button_close( NULL ),
-      m_button_delete( NULL ),
-      m_button_favorite( NULL ),
-      m_button_undo( NULL ),
-      m_button_redo( NULL ),
-      m_button_lock( NULL ),
+      m_button_write( nullptr ),
+      m_button_reload( nullptr ),
+      m_button_stop( nullptr ),
+      m_button_close( nullptr ),
+      m_button_delete( nullptr ),
+      m_button_favorite( nullptr ),
+      m_button_undo( nullptr ),
+      m_button_redo( nullptr ),
+      m_button_lock( nullptr ),
 
-      m_button_back( NULL ),
-      m_button_forward( NULL )
+      m_button_back( nullptr ),
+      m_button_forward( nullptr )
 {
     m_buttonbar.set_border_width( 0 );
-#if GTKMM_CHECK_VERSION(2,12,0)
     m_buttonbar.set_icon_size( Gtk::ICON_SIZE_MENU );
-#endif
     m_buttonbar.set_toolbar_style( Gtk::TOOLBAR_ICONS );
 
 #if GTKMM_CHECK_VERSION(3,0,0)
@@ -256,7 +252,7 @@ void ToolBar::set_relief()
         std::vector< Gtk::Widget* >::iterator it = lists.begin();
         for( ; it != lists.end(); ++it ){
 
-            Gtk::Button* button = NULL;
+            Gtk::Button* button = nullptr;
             Gtk::ToolButton* toolbutton = dynamic_cast< Gtk::ToolButton* >( *it );
             if( toolbutton ) button = dynamic_cast< Gtk::Button* >( toolbutton->get_child() );
             if( ! button ){
@@ -284,7 +280,7 @@ void ToolBar::pack_separator()
 void ToolBar::pack_transparent_separator()
 {
     Gtk::SeparatorToolItem *sep = Gtk::manage( new Gtk::SeparatorToolItem() ); // delete は unpack_buttons() で行う
-    gtk_separator_tool_item_set_draw( sep->gobj(), false );
+    sep->set_draw( false );
     m_buttonbar.append( *sep );
 }
 
@@ -294,11 +290,7 @@ void ToolBar::pack_transparent_separator()
 //
 void ToolBar::set_tooltip( Gtk::ToolItem& toolitem, const std::string& tip )
 {
-#if GTKMM_CHECK_VERSION(2,12,0)
     toolitem.set_tooltip_text( tip );
-#else
-    toolitem.set_tooltip( m_tooltip, tip );
-#endif
 }
 
 
@@ -314,11 +306,7 @@ Gtk::ToolItem* ToolBar::get_label()
         m_ebox_label = Gtk::manage( new Gtk::EventBox );
         m_label = Gtk::manage( new Gtk::Label );
 
-#if GTKMM_CHECK_VERSION(2,6,0)
         m_label->set_ellipsize( Pango::ELLIPSIZE_END );
-#else
-        m_label->set_size_request( 0, 0 );
-#endif
         m_label->set_alignment( Gtk::ALIGN_START );
         m_label->set_selectable( true );
 
@@ -397,9 +385,7 @@ Gtk::Toolbar* ToolBar::get_searchbar()
 {
     if( ! m_searchbar ){
         m_searchbar = Gtk::manage( new SKELETON::JDToolbar() );
-#if GTKMM_CHECK_VERSION(2,12,0)
         m_searchbar->set_icon_size( Gtk::ICON_SIZE_MENU );
-#endif
         m_searchbar->set_toolbar_style( Gtk::TOOLBAR_ICONS );
     }
 
@@ -452,7 +438,7 @@ void ToolBar::close_searchbar()
 Gtk::ToolItem* ToolBar::get_button_open_searchbar()
 {
     if( ! m_button_open_searchbar ){
-        m_button_open_searchbar = Gtk::manage( new SKELETON::ImgToolButton( ICON::SEARCH ) );
+        m_button_open_searchbar = Gtk::manage( new ImgToolButton( ICON::SEARCH, CONTROL::Search ) );
 
         std::string tooltip = "検索バーを開く  " + CONTROL::get_str_motions( CONTROL::Search );
         set_tooltip( *m_button_open_searchbar, tooltip );
@@ -465,7 +451,7 @@ Gtk::ToolItem* ToolBar::get_button_open_searchbar()
 Gtk::ToolItem* ToolBar::get_button_close_searchbar()
 {
     if( ! m_button_close_searchbar ){
-        m_button_close_searchbar = Gtk::manage( new SKELETON::ImgToolButton( ICON::CLOSE_SEARCH ) );
+        m_button_close_searchbar = Gtk::manage( new ImgToolButton( ICON::CLOSE_SEARCH, CONTROL::CloseSearchBar ) );
         set_tooltip( *m_button_close_searchbar, CONTROL::get_label_motions( CONTROL::CloseSearchBar ) );
         m_button_close_searchbar->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_toggle_searchbar ) );
     }
@@ -569,7 +555,7 @@ void ToolBar::slot_operate_search( const int controlid )
     std::cout << "ToolBar::slot_operate_search id = " << controlid << std::endl;
 #endif
 
-    m_admin->set_command( "toolbar_operate_search", m_url, MISC::itostr( controlid ) );
+    m_admin->set_command( "toolbar_operate_search", m_url, std::to_string( controlid ) );
 }
 
 
@@ -587,7 +573,7 @@ void ToolBar::focus_entry_search()
 Gtk::ToolButton* ToolBar::get_button_up_search()
 {
     if( ! m_button_up_search ){
-        m_button_up_search = Gtk::manage( new ImgToolButton( ICON::SEARCH_PREV ) );
+        m_button_up_search = Gtk::manage( new ImgToolButton( ICON::SEARCH_PREV, CONTROL::SearchPrev ) );
         set_tooltip( *m_button_up_search, CONTROL::get_label_motions( CONTROL::SearchPrev ) );
 
         m_button_up_search->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_up_search ) );
@@ -616,7 +602,7 @@ void ToolBar::slot_clicked_up_search()
 Gtk::ToolButton* ToolBar::get_button_down_search()
 {
     if( ! m_button_down_search ){
-        m_button_down_search = Gtk::manage( new ImgToolButton( ICON::SEARCH_NEXT ) );
+        m_button_down_search = Gtk::manage( new ImgToolButton( ICON::SEARCH_NEXT, CONTROL::SearchNext ) );
         set_tooltip( *m_button_down_search, CONTROL::get_label_motions( CONTROL::SearchNext ) );
 
         m_button_down_search->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_down_search ) );
@@ -645,7 +631,7 @@ void ToolBar::slot_clicked_down_search()
 Gtk::ToolButton* ToolBar::get_button_clear_highlight()
 {
     if( ! m_button_clear_highlight ){
-        m_button_clear_highlight = Gtk::manage( new ImgToolButton( ICON::CLEAR_SEARCH ) );
+        m_button_clear_highlight = Gtk::manage( new ImgToolButton( ICON::CLEAR_SEARCH, CONTROL::HiLightOff ) );
         set_tooltip( *m_button_clear_highlight, CONTROL::get_label_motions( CONTROL::HiLightOff ) );
 
         m_button_clear_highlight->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clear_highlight ) );
@@ -706,7 +692,7 @@ void ToolBar::slot_menu_board( int i )
 {
     if( ! m_enable_slot ) return;
 
-    SKELETON::PrefDiag* pref = NULL;
+    SKELETON::PrefDiag* pref = nullptr;
 
     // ToolBar::get_button_board()で作成したメニューの順番に内容を合わせる
     if( i == 0 ) slot_open_board();
@@ -724,10 +710,10 @@ void ToolBar::slot_menu_board( int i )
 //
 // 書き込みボタン
 //
-Gtk::ToolItem* ToolBar::get_button_write()
+Gtk::ToolButton* ToolBar::get_button_write()
 {
     if( ! m_button_write ){
-        m_button_write = Gtk::manage( new ImgToolButton( ICON::WRITE ) );
+        m_button_write = Gtk::manage( new ImgToolButton( ICON::WRITE, CONTROL::WriteMessage ) );
         set_tooltip( *m_button_write, CONTROL::get_label_motions( CONTROL::WriteMessage ) );
 
         m_button_write->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_write ) );
@@ -794,10 +780,10 @@ bool ToolBar::slot_focusout_write_button( GdkEventFocus* event )
 //
 // 再読み込みボタン
 //
-Gtk::ToolItem* ToolBar::get_button_reload()
+Gtk::ToolButton* ToolBar::get_button_reload()
 {
     if( ! m_button_reload ){
-        m_button_reload = Gtk::manage( new ImgToolButton( ICON::RELOAD ) );
+        m_button_reload = Gtk::manage( new ImgToolButton( ICON::RELOAD, CONTROL::Reload ) );
         set_tooltip( *m_button_reload, CONTROL::get_label_motions( CONTROL::Reload ) );
 
         m_button_reload->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_reload ) );
@@ -823,10 +809,10 @@ void ToolBar::slot_clicked_reload()
 //
 // 読み込み停止ボタン
 //
-Gtk::ToolItem* ToolBar::get_button_stop()
+Gtk::ToolButton* ToolBar::get_button_stop()
 {
     if( ! m_button_stop ){
-        m_button_stop = Gtk::manage( new ImgToolButton( ICON::STOPLOADING ) );
+        m_button_stop = Gtk::manage( new ImgToolButton( ICON::STOPLOADING, CONTROL::StopLoading ) );
         set_tooltip( *m_button_stop, CONTROL::get_label_motions( CONTROL::StopLoading ) );
 
         m_button_stop->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_stop ) );
@@ -855,7 +841,7 @@ void ToolBar::slot_clicked_stop()
 Gtk::ToolButton* ToolBar::get_button_close()
 {
     if( ! m_button_close ){
-        m_button_close = Gtk::manage( new ImgToolButton( ICON::QUIT ) );
+        m_button_close = Gtk::manage( new ImgToolButton( ICON::QUIT, CONTROL::Quit ) );
         set_tooltip( *m_button_close, CONTROL::get_label_motions( CONTROL::Quit ) );
 
         m_button_close->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_close ) );
@@ -906,7 +892,7 @@ void ToolBar::slot_clicked_close()
 Gtk::ToolItem* ToolBar::get_button_delete()
 {
     if( ! m_button_delete ){
-        m_button_delete = Gtk::manage( new ImgToolButton( ICON::DELETE ) );
+        m_button_delete = Gtk::manage( new ImgToolButton( ICON::DELETE, CONTROL::Delete ) );
         set_tooltip( *m_button_delete, CONTROL::get_label_motions( CONTROL::Delete ) );
 
         m_button_delete->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_delete ) );
@@ -935,7 +921,7 @@ void ToolBar::slot_clicked_delete()
 Gtk::ToolItem* ToolBar::get_button_favorite()
 {
     if( ! m_button_favorite ){
-        m_button_favorite = Gtk::manage( new ImgToolButton( ICON::APPENDFAVORITE ) );
+        m_button_favorite = Gtk::manage( new ImgToolButton( ICON::APPENDFAVORITE, CONTROL::AppendFavorite ) );
         set_tooltip( *m_button_favorite, CONTROL::get_label_motions( CONTROL::AppendFavorite ) );
 
         m_button_favorite->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_favorite ) );
@@ -964,7 +950,7 @@ void ToolBar::slot_clicked_favorite()
 Gtk::ToolButton* ToolBar::get_button_undo()
 {
     if( ! m_button_undo ){
-        m_button_undo = Gtk::manage( new SKELETON::ImgToolButton( ICON::UNDO ) );
+        m_button_undo = Gtk::manage( new ImgToolButton( ICON::UNDO, CONTROL::Undo ) );
         m_button_undo->set_sensitive( false );
         set_tooltip( *m_button_undo, CONTROL::get_label_motions( CONTROL::Undo ) );
     }
@@ -979,7 +965,7 @@ Gtk::ToolButton* ToolBar::get_button_undo()
 Gtk::ToolButton* ToolBar::get_button_redo()
 {
     if( ! m_button_redo ){
-        m_button_redo = Gtk::manage( new SKELETON::ImgToolButton( ICON::REDO ) );
+        m_button_redo = Gtk::manage( new ImgToolButton( ICON::REDO, CONTROL::Redo ) );
         m_button_redo->set_sensitive( false );
         set_tooltip( *m_button_redo, CONTROL::get_label_motions( CONTROL::Redo ) );
     }
@@ -995,7 +981,8 @@ Gtk::ToolItem* ToolBar::get_button_back()
 {
     if( ! m_button_back ){
 
-        m_button_back = Gtk::manage( new SKELETON::ToolBackForwardButton( "back", false, m_url, true ) );
+        const std::string label = CONTROL::get_label( CONTROL::PrevView );
+        m_button_back = Gtk::manage( new SKELETON::ToolBackForwardButton( label, false, m_url, true ) );
         m_button_back->get_button()->signal_button_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_back ) );
         m_button_back->get_button()->signal_selected().connect( sigc::mem_fun(*this, &ToolBar::slot_selected_back ) );
 
@@ -1028,7 +1015,7 @@ void ToolBar::slot_selected_back( const int i )
     std::cout << "ToolBar::slot_selected_back : " << i << " url = " << m_url << std::endl;
 #endif
 
-    m_admin->set_command( "back_viewhistory", m_url, MISC::itostr( i+1 ) );
+    m_admin->set_command( "back_viewhistory", m_url, std::to_string( i+1 ) );
 }
 
 
@@ -1039,7 +1026,8 @@ Gtk::ToolItem* ToolBar::get_button_forward()
 {
     if( ! m_button_forward ){
 
-        m_button_forward = Gtk::manage( new SKELETON::ToolBackForwardButton( "forward", false, m_url, false ) );
+        const std::string label = CONTROL::get_label( CONTROL::NextView );
+        m_button_forward = Gtk::manage( new SKELETON::ToolBackForwardButton( label, false, m_url, false ) );
         m_button_forward->get_button()->signal_button_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_forward ) );
         m_button_forward->get_button()->signal_selected().connect( sigc::mem_fun(*this, &ToolBar::slot_selected_forward ) );
         set_tooltip( *m_button_forward, CONTROL::get_label_motions( CONTROL::NextView ) );
@@ -1071,19 +1059,18 @@ void ToolBar::slot_selected_forward( const int i )
     std::cout << "ToolBar::slot_selected_forward : " << i << " url = " << m_url << std::endl;
 #endif
 
-    m_admin->set_command( "forward_viewhistory", m_url, MISC::itostr( i+1 ) );
+    m_admin->set_command( "forward_viewhistory", m_url, std::to_string( i+1 ) );
 }
 
 
 //
 // ロックボタン
 //
-Gtk::ToolItem* ToolBar::get_button_lock()
+Gtk::ToolButton* ToolBar::get_button_lock()
 {
     if( ! m_button_lock ){
-        m_button_lock = Gtk::manage( new SKELETON::ImgToggleToolButton( ICON::LOCK ) );
+        m_button_lock = Gtk::manage( new ImgToggleToolButton( ICON::LOCK, CONTROL::Lock ) );
         set_tooltip( *m_button_lock, CONTROL::get_label_motions( CONTROL::Lock ) );
-        m_button_lock->set_label( CONTROL::get_label( CONTROL::Lock ) );
         m_button_lock->signal_clicked().connect( sigc::mem_fun( *this, &ToolBar::slot_lock_clicked ) );
     }
 
