@@ -15,8 +15,6 @@ namespace SKELETON
 {
     class Admin;
     class View;
-    class ImgToolButton;
-    class ImgToggleToolButton;
     class ToolMenuButton;
     class ToolBackForwardButton;
     class BackForwardButton;
@@ -29,10 +27,6 @@ namespace SKELETON
 
         bool m_enable_slot;
 
-#if !GTKMM_CHECK_VERSION(2,12,0)
-        Gtk::Tooltips m_tooltip;
-#endif
-
         // ボタンバー
         SKELETON::JDToolbar m_buttonbar;
         bool m_buttonbar_shown;
@@ -47,11 +41,11 @@ namespace SKELETON
         Gtk::Toolbar* m_searchbar; // 検索バー
         bool m_searchbar_shown;
         bool m_searchbar_packed;
-        SKELETON::ImgToolButton *m_button_open_searchbar;
-        SKELETON::ImgToolButton *m_button_close_searchbar;
-        SKELETON::ImgToolButton *m_button_up_search;
-        SKELETON::ImgToolButton *m_button_down_search;
-        SKELETON::ImgToolButton *m_button_clear_highlight;
+        Gtk::ToolButton* m_button_open_searchbar;
+        Gtk::ToolButton* m_button_close_searchbar;
+        Gtk::ToolButton* m_button_up_search;
+        Gtk::ToolButton* m_button_down_search;
+        Gtk::ToolButton* m_button_clear_highlight;
 
         Gtk::ToolItem* m_tool_search;
         SKELETON::CompletionEntry* m_entry_search;
@@ -61,15 +55,15 @@ namespace SKELETON
         SKELETON::ToolMenuButton* m_button_board;
 
         // その他ボタン
-        SKELETON::ImgToolButton* m_button_write;
-        SKELETON::ImgToolButton* m_button_reload;
-        SKELETON::ImgToolButton* m_button_stop;
-        SKELETON::ImgToolButton* m_button_close;
-        SKELETON::ImgToolButton* m_button_delete;
-        SKELETON::ImgToolButton* m_button_favorite;
-        SKELETON::ImgToolButton* m_button_undo;
-        SKELETON::ImgToolButton* m_button_redo;
-        SKELETON::ImgToggleToolButton* m_button_lock;
+        Gtk::ToolButton* m_button_write;
+        Gtk::ToolButton* m_button_reload;
+        Gtk::ToolButton* m_button_stop;
+        Gtk::ToolButton* m_button_close;
+        Gtk::ToolButton* m_button_delete;
+        Gtk::ToolButton* m_button_favorite;
+        Gtk::ToolButton* m_button_undo;
+        Gtk::ToolButton* m_button_redo;
+        Gtk::ToggleToolButton* m_button_lock;
 
         // 進む、戻るボタン
         SKELETON::ToolBackForwardButton* m_button_back;
@@ -158,15 +152,15 @@ namespace SKELETON
         Gtk::ToolItem* get_button_board();
 
         // その他ボタン
-        Gtk::ToolItem* get_button_write();
-        Gtk::ToolItem* get_button_reload();
-        Gtk::ToolItem* get_button_stop();
+        Gtk::ToolButton* get_button_write();
+        Gtk::ToolButton* get_button_reload();
+        Gtk::ToolButton* get_button_stop();
         Gtk::ToolButton* get_button_close();
         Gtk::ToolItem* get_button_delete();
         Gtk::ToolItem* get_button_favorite();
         Gtk::ToolButton* get_button_undo();
         Gtk::ToolButton* get_button_redo();
-        Gtk::ToolItem* get_button_lock();
+        Gtk::ToolButton* get_button_lock();
 
         Gtk::ToolItem* get_button_back();
         Gtk::ToolItem* get_button_forward();
