@@ -14,15 +14,20 @@ namespace SKELETON
 
     class ToolBarNotebook : public Gtk::Notebook
     {
+#if !GTKMM_CHECK_VERSION(3,0,0)
         DragableNoteBook* m_parent;
+#endif
 
       public:
 
         ToolBarNotebook( DragableNoteBook* parent );
+        ~ToolBarNotebook() noexcept;
 
+#if !GTKMM_CHECK_VERSION(3,0,0)
       protected:
 
         bool on_expose_event( GdkEventExpose* event ) override;
+#endif
     };
 }
 
