@@ -14,17 +14,22 @@ namespace SKELETON
 
     class ViewNotebook : public Gtk::Notebook
     {
+#if !GTKMM_CHECK_VERSION(3,0,0)
         DragableNoteBook* m_parent;
+#endif
 
       public:
 
         ViewNotebook( DragableNoteBook* parent );
+        ~ViewNotebook() noexcept;
 
         void redraw_scrollbar();
 
+#if !GTKMM_CHECK_VERSION(3,0,0)
       protected:
 
         bool on_expose_event( GdkEventExpose* event ) override;
+#endif
     };
 }
 
