@@ -23,7 +23,7 @@
 
 #include "config/globalconf.h"
 
-CORE::Usrcmd_Manager* instance_usrcmd_manager = NULL;
+CORE::Usrcmd_Manager* instance_usrcmd_manager = nullptr;
 
 CORE::Usrcmd_Manager* CORE::get_usrcmd_manager()
 {
@@ -37,7 +37,7 @@ CORE::Usrcmd_Manager* CORE::get_usrcmd_manager()
 void CORE::delete_usrcmd_manager()
 {
     if( instance_usrcmd_manager ) delete instance_usrcmd_manager;
-    instance_usrcmd_manager = NULL;
+    instance_usrcmd_manager = nullptr;
 }
 
 ///////////////////////////////////////////////
@@ -215,7 +215,7 @@ void Usrcmd_Manager::exec( const std::string command, // コマンド
 
     if( use_browser ) CORE::core_set_command( "open_url_browser", cmd );
     else if( show_dialog ){
-        SKELETON::MsgDiag mdiag( NULL, cmd );
+        SKELETON::MsgDiag mdiag( nullptr, cmd );
         mdiag.run();
     }
     else Glib::spawn_command_line_async( cmd );
@@ -229,7 +229,7 @@ bool Usrcmd_Manager::show_replacetextdiag( std::string& texti, const std::string
 {
     if( ! texti.empty() ) return true;
 
-    ReplaceTextDiag textdiag( NULL, title );
+    ReplaceTextDiag textdiag( nullptr, title );
     if( textdiag.run() != Gtk::RESPONSE_OK ) return false;
     texti = textdiag.get_text();
     return true;
@@ -255,7 +255,7 @@ std::string Usrcmd_Manager::replace_cmd( const std::string& cmd,
     cmd_out = MISC::replace_str( cmd_out, "$LOCALDATL", CACHE::path_dat( link ) );
     cmd_out = MISC::replace_str( cmd_out, "$LOCALDAT", CACHE::path_dat( url ) );
     cmd_out = MISC::replace_str( cmd_out, "$LINK", link );
-    cmd_out = MISC::replace_str( cmd_out, "$NUMBER", MISC::itostr( number ) );
+    cmd_out = MISC::replace_str( cmd_out, "$NUMBER", std::to_string( number ) );
 
     if( cmd_out.find( "$CACHEDIMG" ) != std::string::npos ){
         cmd_out = MISC::replace_str( cmd_out, "$CACHEDIMG", DBIMG::get_cache_path( link ) );
@@ -469,7 +469,7 @@ std::string Usrcmd_Manager::create_usrcmd_menu( Glib::RefPtr< Gtk::ActionGroup >
 #ifdef _DEBUG
                 std::cout << "[" << dirno << "] " << name << std::endl;
 #endif
-                const std::string dirname = "usrcmd_dir" + MISC::itostr( dirno );
+                const std::string dirname = "usrcmd_dir" + std::to_string( dirno );
                 action_group->add( Gtk::Action::create( dirname, name ) );
                 ++dirno;
 
@@ -489,7 +489,7 @@ std::string Usrcmd_Manager::create_usrcmd_menu( Glib::RefPtr< Gtk::ActionGroup >
 #ifdef _DEBUG
                     std::cout << "[" << cmdno << "] " << name << std::endl;
 #endif
-                    const std::string cmdname = "usrcmd" + MISC::itostr( cmdno );
+                    const std::string cmdname = "usrcmd" + std::to_string( cmdno );
                     action_group->add( Gtk::Action::create( cmdname, name ) );
                     ++cmdno;
 
@@ -507,7 +507,7 @@ std::string Usrcmd_Manager::create_usrcmd_menu( Glib::RefPtr< Gtk::ActionGroup >
 
 Glib::RefPtr< Gtk::Action > Usrcmd_Manager::get_action( Glib::RefPtr< Gtk::ActionGroup >& action_group, const int num )
 {
-    const std::string str_cmd = "usrcmd" + MISC::itostr( num );
+    const std::string str_cmd = "usrcmd" + std::to_string( num );
     return action_group->get_action( str_cmd );
 }
 
@@ -526,7 +526,6 @@ void Usrcmd_Manager::toggle_sensitive( Glib::RefPtr< Gtk::ActionGroup >& action_
         Glib::RefPtr< Gtk::Action > act = get_action( action_group, i );
         if( act ){
 
-#if GTKMM_CHECK_VERSION(2,6,0)
             if( is_hide( i, url_article ) ) act->set_visible( false );
             else{
 
@@ -539,10 +538,6 @@ void Usrcmd_Manager::toggle_sensitive( Glib::RefPtr< Gtk::ActionGroup >& action_
                     if( CONFIG::get_hide_usrcmd() ) act->set_visible( false );
                 }
             }
-#else
-            if( is_sensitive( i, url_link, str_select ) ) act->set_sensitive( true );
-            else act->set_sensitive( false );
-#endif
         }
     }
 }
