@@ -72,11 +72,6 @@ UsrCmdPref::UsrCmdPref( Gtk::Window* parent, const std::string& url )
       m_ckbt_hide_usrcmd( "選択不可のユーザコマンドを非表示にする", true )
 {
     m_treestore = Gtk::TreeStore::create( m_columns );
-#if !GTKMM_CHECK_VERSION(2,7,0)
-    // gtkmm26以下にはunset_model()が無いのでここでset_model()しておく
-    // それ以上は m_treeview.xml2tree() でセットする
-    m_treeview.set_treestore( m_treestore );
-#endif
     m_treeview.create_column( 0 );
     m_treeview.set_editable_view( true );
 
@@ -96,10 +91,8 @@ UsrCmdPref::UsrCmdPref( Gtk::Window* parent, const std::string& url )
     get_vbox()->pack_start( m_label, Gtk::PACK_SHRINK );
     get_vbox()->pack_start( m_scrollwin );
 
-#if GTKMM_CHECK_VERSION(2,7,0)
     m_ckbt_hide_usrcmd.set_active( CONFIG::get_hide_usrcmd() );
     get_vbox()->pack_start( m_ckbt_hide_usrcmd, Gtk::PACK_SHRINK );
-#endif
 
     // ポップアップメニュー
     m_action_group = Gtk::ActionGroup::create();
@@ -248,7 +241,7 @@ bool UsrCmdPref::slot_key_release( GdkEventKey* event )
 // ポップアップメニュー表示
 void UsrCmdPref::show_popupmenu()
 {
-    Gtk::Menu* menu = NULL;
+    Gtk::Menu* menu = nullptr;
     std::list< Gtk::TreeModel::iterator > list_it = m_treeview.get_selected_iterators();
     if( list_it.size() <= 1 ) menu = dynamic_cast< Gtk::Menu* >( m_ui_manager->get_widget( "/popup_menu" ) );
     else menu = dynamic_cast< Gtk::Menu* >( m_ui_manager->get_widget( "/popup_menu_mul" ) );
@@ -290,7 +283,7 @@ void UsrCmdPref::slot_newcmd()
         CORE::DATA_INFO_LIST list_info;
         CORE::DATA_INFO info;
         info.type = TYPE_USRCMD;
-        info.parent = NULL;
+        info.parent = nullptr;
         info.url = std::string();
         info.name = diag.get_name();
         info.data = diag.get_cmd();
@@ -322,7 +315,7 @@ void UsrCmdPref::slot_newsepa()
     CORE::DATA_INFO_LIST list_info;
     CORE::DATA_INFO info;
     info.type = TYPE_SEPARATOR;
-    info.parent = NULL;
+    info.parent = nullptr;
     info.url = std::string();
     info.name = "--- 区切り ---";
     info.data = std::string();
@@ -345,7 +338,7 @@ void UsrCmdPref::slot_newsepa()
 //
 void UsrCmdPref::delete_row()
 {
-    SKELETON::MsgDiag mdiag( NULL, "削除しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+    SKELETON::MsgDiag mdiag( nullptr, "削除しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
     if( mdiag.run() != Gtk::RESPONSE_YES ) return;
 
     slot_delete();
